(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    171824,       3750]
NotebookOptionsPosition[    165010,       3534]
NotebookOutlinePosition[    165776,       3564]
CellTagsIndexPosition[    165646,       3558]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Pyridone + H2O DG-EVB in redundant internal coordinates", "Subtitle",
 CellChangeTimes->{{3.42160516418307*^9, 3.42160517143911*^9}, {
  3.442683064096397*^9, 3.442683080664949*^9}}],

Cell[TextData[{
 StyleBox["Notes:",
  FontWeight->"Bold"],
 "\n   \nThis notebook reads fchk files containing coordinates, energies, \
gradients and hessians for reactant, product, transition state, and \
additional points on the surface.\n\n###############\n Gaussian stores all \
values in a.u. and standard orientation in the fchk file\n\n Distance = bohrs\
\n Angles = radian\n Energy = hartree\n Gradient = hartree/bohr\n Hessian = \
hartree/bohr^2\n###############\n\nThe notebook reads an IRC fchk file (from \
the HPC IRC following algorithm located in L123.exe, the corrected \
coordinates and energies are read)\n\nA reduced number of internal \
coordinates can be used to fit V12sq (see the EVB Surface Fitting section)\nA \
reduced number of points can be used for the distributed Gussian fit (see the \
EVB Surface Fitting section)\n\nTo perform an EVB fit, update the \
SetDirectory statement and any other options in input section, then evaluate \
the outermost cell over here.  ",
 StyleBox["---------------------------->",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.4211658572262583`*^9, 3.421165860565464*^9}, {
  3.421165918505851*^9, 3.4211659992892523`*^9}, {3.421583346865282*^9, 
  3.421583425893856*^9}, {3.421583527849957*^9, 3.421583568182987*^9}, {
  3.421583926020019*^9, 3.421583926485379*^9}}],

Cell[CellGroupData[{

Cell["Preliminaries", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"$TextStyle", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
    RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"FontFamily", "\[Rule]", "\<\"Helvetica\"\>"}], ",", 
   RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]], "Output",
 CellChangeTimes->{3.414419850629141*^9, 3.41442014204252*^9, 
  3.414428970352681*^9, 3.414429206555746*^9, 3.4144293109576187`*^9, 
  3.414429662473585*^9, 3.414432352296838*^9, 3.4144324789748783`*^9, 
  3.414433100715501*^9, 3.4144372151000347`*^9, 3.414437826907754*^9, 
  3.4148477853264513`*^9, 3.414847816710454*^9, 3.414848182848474*^9, 
  3.414850212576535*^9, 3.421605307663869*^9, 3.425071984150858*^9, 
  3.437427062300274*^9, 3.4426831495063*^9, 3.442683226622067*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"<<", "Chemistry`EVB`"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input", "Section"],

Cell["\<\
To avoid clobbering variables of similiar names, please use variable names of \
the form iName to hold inputted data.\
\>", "Text",
 CellChangeTimes->{{3.44268321850921*^9, 3.442683218981309*^9}}],

Cell[CellGroupData[{

Cell["Set working directory", "Subsection",
 ScreenStyleEnvironment->"Presentation",
 PrintingStyleEnvironment->"Presentation",
 ShowCellLabel->False,
 Magnification->1.25],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "SetDirectory", "[", 
   "\"\</Users/jsonnenb/Documents/Research/ONR/EVB \
fits/pyridoneh2o_gas_67\>\"", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.421605208904003*^9, 3.4216052112337112`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
File names. All files must have the same number of redundant internal \
coordinates. \
\>", "Subsection",
 ScreenStyleEnvironment->"Presentation",
 PrintingStyleEnvironment->"Presentation",
 ShowCellLabel->False,
 Magnification->1.25],

Cell[BoxData[{
 RowBox[{
  RowBox[{"iReactant", "=", "\"\<PYW_mp2_67.fchk\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iProduct", "=", "\"\<2hydroxypyridineW_mp2_67.fchk\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iTS", "=", "\"\<TSW_mp2_67.fchk\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iOtherPoints", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<TSW_onefourthR_67.fchk\>\"", ",", "\"\<TSW_onefourthP_67.fchk\>\""}],
     "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.414259344847707*^9, 3.414259352151561*^9}, {
   3.414259416171824*^9, 3.414259417464231*^9}, {3.41441993392694*^9, 
   3.414419956379827*^9}, {3.414847731585988*^9, 3.414847739618442*^9}, 
   3.414847974634118*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{
    "data", " ", "points", " ", "along", " ", "IRC", " ", "that", " ", "are", 
     " ", "used", " ", "for", " ", "analyzing", " ", "the", " ", "EVB", " ", 
     RowBox[{"fit", "."}]}], " ", "*)"}],
   FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"IRCFile", "=", "\"\<TSW_irc3.fchk\>\""}], ";"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"A", " ", "2"}], "-", 
     RowBox[{"D", " ", "PES", " ", 
      RowBox[{"scan", "."}]}]}], " ", "*)"}],
   FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"GridFile", "=", "\"\<\>\""}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"GridCoordX", "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"GridCoordY", "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Ngrid", "=", "0"}], ";"}]}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Repulsive Term coordinates", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"icoordV11", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"11", ",", "12", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"14", ",", "15", ",", "0", ",", "0"}], "}"}]}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"icoordV22", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "15", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "14", ",", "0", ",", "0"}], "}"}]}], "}"}]}], 
  ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Control the use of gradients and Hessians in the DG fit at points other than \
the TS.\
\>", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"iNoGrad", "=", "False"}], ";", 
  RowBox[{"iNoHess", "=", "False"}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Enable figure file generation for manuscripts and the like.", \
"Subsection",
 ScreenStyleEnvironment->"Presentation",
 PrintingStyleEnvironment->"Presentation",
 ShowCellLabel->False,
 Magnification->1.25],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"iFigures", "=", "0"}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.414419854531974*^9, 3.414420144542733*^9, 
  3.414428972874384*^9, 3.4144292102301893`*^9, 3.414429314064578*^9, 
  3.4144296655821657`*^9, 3.414432354510393*^9, 3.414432481969865*^9, 
  3.414433104411874*^9, 3.414437216258226*^9, 3.4144378312060823`*^9, 
  3.414847787328779*^9, 3.414847817746149*^9, 3.414848187723981*^9, 
  3.414850213413941*^9, 3.421605309751626*^9, 3.425071987197854*^9, 
  3.4374270870771313`*^9, 3.4426832285619793`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Enable use of previously determined beta as starting guess.", \
"Subsection",
 ScreenStyleEnvironment->"Presentation",
 PrintingStyleEnvironment->"Presentation",
 ShowCellLabel->False,
 CellChangeTimes->{{3.434827059397477*^9, 3.434827075946116*^9}},
 Magnification->1.25],

Cell[BoxData[
 RowBox[{
  RowBox[{"iBeta", "=", "True"}], ";"}]], "Input",
 CellChangeTimes->{
  3.4348269884069633`*^9, {3.434827084349894*^9, 3.434827102376202*^9}, {
   3.435000846343*^9, 3.435000848028*^9}, {3.435007303237*^9, 
   3.435007304959*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Enable debugging checks and dump printing.", "Subsection",
 ScreenStyleEnvironment->"Presentation",
 PrintingStyleEnvironment->"Presentation",
 ShowCellLabel->False,
 Magnification->1.25],

Cell[BoxData[
 RowBox[{
  RowBox[{"iDebug", "=", "10"}], ";", 
  RowBox[{"iDump", "=", "1"}], ";"}]], "Input",
 CellChangeTimes->{3.437427082694024*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions", "Section"],

Cell[CellGroupData[{

Cell["Display MB of memory currently in use", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MBinUse", "[", "]"}], ":=", 
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Currently using \>\"", ",", 
    RowBox[{"N", "[", 
     RowBox[{
      RowBox[{"MemoryInUse", "[", "]"}], "/", 
      SuperscriptBox["2", "20"]}], "]"}], ",", "\"\< MB of memory.\>\""}], 
   "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Condition Number of a matrix. May blow up if the matrix is not invertible.\
\>", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OneNorm", "[", "m_", "]"}], ":=", 
  RowBox[{"Max", "[", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Norm", "[", 
       RowBox[{"#", ",", "1"}], "]"}], "&"}], ",", "m"}], "]"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TwoNorm", "[", "m_", "]"}], ":=", 
  RowBox[{"Max", "[", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Norm", "[", 
       RowBox[{"#", ",", "2"}], "]"}], "&"}], ",", "m"}], "]"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ConditionNumber2", "[", "m_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"TwoNorm", "[", 
    RowBox[{"Inverse", "[", "m", "]"}], "]"}], "*", 
   RowBox[{"TwoNorm", "[", "m", "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ConditionNumber", "[", "m_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"OneNorm", "[", 
    RowBox[{"Inverse", "[", "m", "]"}], "]"}], "*", 
   RowBox[{"OneNorm", "[", "m", "]"}]}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBinUse", "[", "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Currently using \"\>", "\[InvisibleSpace]", 
   "8.650367736816406`", "\[InvisibleSpace]", "\<\" MB of memory.\"\>"}],
  SequenceForm["Currently using ", 8.650367736816406, " MB of memory."],
  Editable->False]], "Print",
 CellChangeTimes->{3.414419859487604*^9, 3.414420146821656*^9, 
  3.414428975038002*^9, 3.4144292117267036`*^9, 3.414429315778183*^9, 
  3.414429667641551*^9, 3.414432355588038*^9, 3.414432484589705*^9, 
  3.414433105884285*^9, 3.414437217059903*^9, 3.4144378327582283`*^9, 
  3.4148477883315573`*^9, 3.414847819406413*^9, 3.414848243328471*^9, 
  3.4148502140958557`*^9, 3.421605310720994*^9, 3.425071989883148*^9, 
  3.437427095136674*^9, 3.4426832366876783`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Generate EVB surface", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nDG", "=", "5"}]], "Input",
 CellChangeTimes->{3.414252439601102*^9, 3.4144201843508863`*^9, 
  3.414428951601087*^9, 3.414438459988475*^9, 3.414439159144891*^9, 
  3.414847807624042*^9, 3.414848238552149*^9, 3.442683452545624*^9, 
  3.442683503655789*^9, 3.442683570234818*^9, 3.442683614186151*^9, 
  3.442683652745674*^9}],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{
  3.414419862290991*^9, 3.414420147150834*^9, 3.414428975286566*^9, 
   3.4144292127269278`*^9, 3.414429315994668*^9, 3.414429667986122*^9, 
   3.4144323559142847`*^9, 3.414432485025083*^9, 3.414433106301774*^9, 
   3.414437217203361*^9, 3.414437833606924*^9, 3.41443847425639*^9, 
   3.4144391673622704`*^9, 3.414440365780889*^9, 3.4144968342710648`*^9, 
   3.4144985382253647`*^9, 3.414500376636146*^9, 3.414501880270843*^9, 
   3.4145045379440947`*^9, 3.4145073851152267`*^9, 3.414508919550889*^9, 
   3.4148477886265087`*^9, 3.4148478195456944`*^9, 3.414848245806682*^9, 
   3.414850214265835*^9, 3.414853936904812*^9, 3.421605310848735*^9, 
   3.42507199001196*^9, 3.437427170743012*^9, 3.442683307372821*^9, 
   3.442683459080914*^9, 3.44268350594213*^9, 3.4426835731371117`*^9, {
   3.44268361486979*^9, 3.442683618719426*^9}, 3.442683655876176*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"reactant", ",", " ", "product", ",", " ", "TS", ",", " ", 
    RowBox[{"others", ";", " ", 
     RowBox[{
      RowBox[{"except", " ", "for", " ", "nDG"}], "=", "1"}]}]}], " ", "*)"}],
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"UseRP", "=", "True"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Switch", "[", 
     RowBox[{"nDG", ",", "\[IndentingNewLine]", "5", ",", 
      RowBox[{
       RowBox[{"alpha", "=", 
        RowBox[{"{", 
         RowBox[{"1.2", ",", "1.3", ",", "1.9", ",", "1.8", ",", "1.8"}], 
         "}"}]}], ";"}], ",", "\[IndentingNewLine]", "3", ",", 
      RowBox[{
       RowBox[{"alpha", "=", 
        RowBox[{"{", 
         RowBox[{"1.2", ",", "1.3", ",", " ", "1.8"}], "}"}]}], ";"}], ",", 
      "\[IndentingNewLine]", "1", ",", 
      RowBox[{
       RowBox[{"alpha", "=", 
        RowBox[{"{", "1.76", "}"}]}], ";", 
       RowBox[{"UseRP", "=", "False"}], ";"}]}], "\[IndentingNewLine]", "]"}],
     ";"}]}]}]], "Input",
 CellChangeTimes->{{3.414419976463443*^9, 3.414420001166106*^9}, {
  3.414420062714052*^9, 3.414420066911007*^9}, {3.414420186119712*^9, 
  3.4144201895318413`*^9}, {3.414440337968959*^9, 3.4144403394565573`*^9}, {
  3.414496816801017*^9, 3.414496831553938*^9}, {3.414498513038101*^9, 
  3.414498517844205*^9}, {3.4145003470267973`*^9, 3.414500355651784*^9}, {
  3.414501836405695*^9, 3.4145018684077253`*^9}, {3.414504198950994*^9, 
  3.4145042000994864`*^9}, {3.414504515823308*^9, 3.414504535088539*^9}, {
  3.4145073791006393`*^9, 3.414507380603959*^9}, {3.414508894963291*^9, 
  3.414508899199864*^9}, {3.414847701850129*^9, 3.41484771744911*^9}, {
  3.414850201393832*^9, 3.41485020286551*^9}, {3.414853909749694*^9, 
  3.414853931870832*^9}, {3.437427159554875*^9, 3.43742716596988*^9}, {
  3.442683499183728*^9, 3.442683500335394*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"previously", " ", "determined", " ", "$B", " ", "values"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"betafilename", "=", 
     RowBox[{"\"\<Beta-\>\"", "<>", 
      RowBox[{"ToString", "[", "nDG", "]"}], "<>", "\"\<.txt\>\""}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Count", "[", 
         RowBox[{
          RowBox[{"FileNames", "[", "]"}], ",", "betafilename"}], "]"}], 
        "\[Equal]", "1"}], " ", "&&", " ", "iBeta"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Guess", "=", 
        RowBox[{"ReadList", "[", 
         RowBox[{"betafilename", ",", "Number"}], "]"}]}], ";"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Guess", "=", "Automatic"}], ";"}]}], "\[IndentingNewLine]", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Length", "[", "Guess", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.434826774981058*^9, 3.434826813971819*^9}, 
   3.434827020475934*^9, {3.434827118861854*^9, 3.434827137802361*^9}, {
   3.4348272794057903`*^9, 3.434827283568796*^9}, {3.4348274080212593`*^9, 
   3.434827480216357*^9}, {3.434827634674159*^9, 3.4348276792732973`*^9}, {
   3.434827751919635*^9, 3.4348277813294573`*^9}, {3.434829639050087*^9, 
   3.434829640813073*^9}, {3.43482969597332*^9, 3.434829777685588*^9}, {
   3.4348299842914867`*^9, 3.434830014241911*^9}, {3.434830124518196*^9, 
   3.434830139091716*^9}, {3.434831212882193*^9, 3.4348312181855307`*^9}}],

Cell[BoxData["11730"], "Output",
 CellChangeTimes->{3.437427171130034*^9, 3.442683308052919*^9, 
  3.4426834594436283`*^9, 3.442683506670425*^9, 3.442683573471781*^9, 
  3.4426836190843773`*^9, 3.442683656897434*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "EVB", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Alpha", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"AlphaMultiplier", "\[Rule]", "1.1`"}], ",", 
   RowBox[{"AlphaThreshold", "\[Rule]", "15"}], ",", 
   RowBox[{"AverageAlpha", "\[Rule]", "False"}], ",", 
   RowBox[{"CheckTS", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotIRC", "\[Rule]", "True"}], ",", 
   RowBox[{"RepulsivePotential", "\[Rule]", "True"}], ",", 
   RowBox[{"ReverseIRC", "\[Rule]", "False"}], ",", 
   RowBox[{"ScaleFactor", "\[Rule]", "1"}], ",", 
   RowBox[{"StartGuess", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"UseReactantAndProduct", "\[Rule]", "True"}], ",", 
   RowBox[{"V11Coord", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], ",", 
   RowBox[{"V22Coord", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], ",", 
   RowBox[{"V12Coordinates", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"V12CoordinateTolerance", "\[Rule]", "0"}], ",", 
   RowBox[{"DebugPrint", "\[Rule]", "1"}], ",", 
   RowBox[{"MaxIterations", "\[Rule]", "1000"}], ",", 
   RowBox[{"ResidualPlot", "\[Rule]", "True"}], ",", 
   RowBox[{"Tolerance", "\[Rule]", "1.`*^-9"}]}], "}"}]], "Output",
 CellChangeTimes->{3.414419862756371*^9, 3.4144201480661917`*^9, 
  3.414428975885062*^9, 3.414429213815433*^9, 3.414429316926567*^9, 
  3.414429668931283*^9, 3.414432356682941*^9, 3.4144324855944347`*^9, 
  3.4144331071993113`*^9, 3.414437217411901*^9, 3.414437834340291*^9, 
  3.414438474683125*^9, 3.414439167956806*^9, 3.4144403662960997`*^9, 
  3.414496834773449*^9, 3.4144985386766148`*^9, 3.41450037711143*^9, 
  3.4145018809813128`*^9, 3.4145045384257183`*^9, 3.4145073857851543`*^9, 
  3.414508920800877*^9, 3.414847789245998*^9, 3.414847819752179*^9, 
  3.414848246338621*^9, 3.4148502144965*^9, 3.41485393734832*^9, 
  3.421605311396944*^9, 3.425071990223012*^9, 3.437427171304237*^9, 
  3.44268330842589*^9, 3.44268345960071*^9, 3.442683506831565*^9, 
  3.442683573597105*^9, 3.4426836192047873`*^9, 3.442683657208549*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "EVB"}]], "Input",
 CellChangeTimes->{{3.414419886790182*^9, 3.414419887538066*^9}}],

Cell[BoxData[
 StyleBox["\<\"EVB[Reactant,Product,TS,AdditionalPoints,IRC] fits an \
empirical valence bond potential energy surface.\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.4426836576276703`*^9},
 CellTags->"Info3442665657-4847696"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EVB", "[", 
  RowBox[{"iReactant", ",", "iProduct", ",", "iTS", ",", 
   RowBox[{"Take", "[", 
    RowBox[{"iOtherPoints", ",", 
     RowBox[{"Max", "[", 
      RowBox[{"0", ",", 
       RowBox[{"nDG", "-", "3"}]}], "]"}]}], "]"}], ",", "IRCFile", ",", 
   RowBox[{"V11Coord", "\[Rule]", "icoordV11"}], ",", 
   RowBox[{"V22Coord", "\[Rule]", "icoordV22"}], ",", 
   RowBox[{"Alpha", "\[Rule]", "alpha"}], ",", 
   RowBox[{"RepulsivePotential", "\[Rule]", "True"}], ",", 
   RowBox[{"ScaleFactor", "\[Rule]", 
    RowBox[{"1", "/", "10"}]}], ",", 
   RowBox[{"ReverseIRC", "\[Rule]", "True"}], ",", 
   RowBox[{"UseReactantAndProduct", "\[Rule]", "UseRP"}], ",", 
   RowBox[{"StartGuess", "->", "Guess"}], ",", 
   RowBox[{"DebugPrint", "\[Rule]", "iDebug"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.414244072436825*^9, 3.414244072854319*^9}, {
  3.414244998480036*^9, 3.4142450104327707`*^9}, {3.414245815554372*^9, 
  3.4142458159103603`*^9}, {3.414246487995935*^9, 3.414246493902968*^9}, {
  3.414247238115593*^9, 3.414247242200777*^9}, {3.414249733330031*^9, 
  3.4142497337725153`*^9}, {3.4144197957016897`*^9, 3.414419813838718*^9}, {
  3.414420073678183*^9, 3.4144200741396713`*^9}, {3.414437176107411*^9, 
  3.414437204713867*^9}, {3.414437981589622*^9, 3.414437981978017*^9}, {
  3.4374271316106853`*^9, 3.4374271383373013`*^9}, {3.4374271909643707`*^9, 
  3.437427192036425*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The repulsion coefficient was set to \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["1", "10"], "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["The repulsion coefficient was set to ", 
   Rational[1, 10], "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.442683658029866*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The \\!\\(\\*SubscriptBox[\\\"V\\\", \\\"11\\\"]\\) repulsive \
coordinates are \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"11", ",", "12", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"14", ",", "15", ",", "0", ",", "0"}], "}"}]}], "}"}], 
   "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "The \!\(\*SubscriptBox[\"V\", \"11\"]\) repulsive coordinates are ", {{11, 
   12, 0, 0}, {14, 15, 0, 0}}, "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.4426836581504*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The \\!\\(\\*SubscriptBox[\\\"V\\\", \\\"22\\\"]\\) repulsive \
coordinates are \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "15", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "14", ",", "0", ",", "0"}], "}"}]}], "}"}], 
   "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "The \!\(\*SubscriptBox[\"V\", \"22\"]\) repulsive coordinates are ", {{6, 
   15, 0, 0}, {12, 14, 0, 0}}, "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.442683658313661*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "5", "\[InvisibleSpace]", "\<\" points will be used in the EVB PES \
fit.\"\>"}],
  SequenceForm[5, " points will be used in the EVB PES fit."],
  Editable->False]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.4426836584425087`*^9}],

Cell[BoxData["\<\"The following files were passed to EVB:\"\>"], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.4426836585494213`*^9}],

Cell[BoxData["\<\"PYW_mp2_67.fchk\"\>"], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.442683658687131*^9}],

Cell[BoxData["\<\"2hydroxypyridineW_mp2_67.fchk\"\>"], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.442683658851272*^9}],

Cell[BoxData["\<\"TSW_mp2_67.fchk\"\>"], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.442683658980165*^9}],

Cell[BoxData["\<\"TSW_onefourthR_67.fchk\"\>"], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.442683659123218*^9}],

Cell[BoxData["\<\"TSW_onefourthP_67.fchk\"\>"], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.4426836592423553`*^9}],

Cell[BoxData["\<\"TSW_irc3.fchk\"\>"], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.442683659390167*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The alpha multiplier was set to \"\>", "\[InvisibleSpace]", 
   "1.1`", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["The alpha multiplier was set to ", 1.1, "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.442683659489134*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The molecular system contains \"\>", "\[InvisibleSpace]", "15",
    "\[InvisibleSpace]", "\<\" atoms.\"\>"}],
  SequenceForm["The molecular system contains ", 15, " atoms."],
  Editable->False]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.4426836596388903`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Read in \"\>", "\[InvisibleSpace]", "67", 
   "\[InvisibleSpace]", "\<\" internal coordinates.\"\>"}],
  SequenceForm["Read in ", 67, " internal coordinates."],
  Editable->False]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.442683659746183*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "0", ",", "0"}], "}"}]},
     {"2", 
      RowBox[{"{", 
       RowBox[{"1", ",", "6", ",", "0", ",", "0"}], "}"}]},
     {"3", 
      RowBox[{"{", 
       RowBox[{"1", ",", "11", ",", "0", ",", "0"}], "}"}]},
     {"4", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "0", ",", "0"}], "}"}]},
     {"5", 
      RowBox[{"{", 
       RowBox[{"2", ",", "8", ",", "0", ",", "0"}], "}"}]},
     {"6", 
      RowBox[{"{", 
       RowBox[{"3", ",", "4", ",", "0", ",", "0"}], "}"}]},
     {"7", 
      RowBox[{"{", 
       RowBox[{"3", ",", "7", ",", "0", ",", "0"}], "}"}]},
     {"8", 
      RowBox[{"{", 
       RowBox[{"4", ",", "5", ",", "0", ",", "0"}], "}"}]},
     {"9", 
      RowBox[{"{", 
       RowBox[{"4", ",", "9", ",", "0", ",", "0"}], "}"}]},
     {"10", 
      RowBox[{"{", 
       RowBox[{"5", ",", "6", ",", "0", ",", "0"}], "}"}]},
     {"11", 
      RowBox[{"{", 
       RowBox[{"5", ",", "10", ",", "0", ",", "0"}], "}"}]},
     {"12", 
      RowBox[{"{", 
       RowBox[{"6", ",", "15", ",", "0", ",", "0"}], "}"}]},
     {"13", 
      RowBox[{"{", 
       RowBox[{"11", ",", "12", ",", "0", ",", "0"}], "}"}]},
     {"14", 
      RowBox[{"{", 
       RowBox[{"12", ",", "14", ",", "0", ",", "0"}], "}"}]},
     {"15", 
      RowBox[{"{", 
       RowBox[{"13", ",", "14", ",", "0", ",", "0"}], "}"}]},
     {"16", 
      RowBox[{"{", 
       RowBox[{"14", ",", "15", ",", "0", ",", "0"}], "}"}]},
     {"17", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "6", ",", "0"}], "}"}]},
     {"18", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "11", ",", "0"}], "}"}]},
     {"19", 
      RowBox[{"{", 
       RowBox[{"6", ",", "1", ",", "11", ",", "0"}], "}"}]},
     {"20", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "0"}], "}"}]},
     {"21", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "8", ",", "0"}], "}"}]},
     {"22", 
      RowBox[{"{", 
       RowBox[{"3", ",", "2", ",", "8", ",", "0"}], "}"}]},
     {"23", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "4", ",", "0"}], "}"}]},
     {"24", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "7", ",", "0"}], "}"}]},
     {"25", 
      RowBox[{"{", 
       RowBox[{"4", ",", "3", ",", "7", ",", "0"}], "}"}]},
     {"26", 
      RowBox[{"{", 
       RowBox[{"3", ",", "4", ",", "5", ",", "0"}], "}"}]},
     {"27", 
      RowBox[{"{", 
       RowBox[{"3", ",", "4", ",", "9", ",", "0"}], "}"}]},
     {"28", 
      RowBox[{"{", 
       RowBox[{"5", ",", "4", ",", "9", ",", "0"}], "}"}]},
     {"29", 
      RowBox[{"{", 
       RowBox[{"4", ",", "5", ",", "6", ",", "0"}], "}"}]},
     {"30", 
      RowBox[{"{", 
       RowBox[{"4", ",", "5", ",", "10", ",", "0"}], "}"}]},
     {"31", 
      RowBox[{"{", 
       RowBox[{"6", ",", "5", ",", "10", ",", "0"}], "}"}]},
     {"32", 
      RowBox[{"{", 
       RowBox[{"1", ",", "6", ",", "5", ",", "0"}], "}"}]},
     {"33", 
      RowBox[{"{", 
       RowBox[{"1", ",", "6", ",", "15", ",", "0"}], "}"}]},
     {"34", 
      RowBox[{"{", 
       RowBox[{"5", ",", "6", ",", "15", ",", "0"}], "}"}]},
     {"35", 
      RowBox[{"{", 
       RowBox[{"1", ",", "11", ",", "12", ",", "0"}], "}"}]},
     {"36", 
      RowBox[{"{", 
       RowBox[{"11", ",", "12", ",", "14", ",", "0"}], "}"}]},
     {"37", 
      RowBox[{"{", 
       RowBox[{"12", ",", "14", ",", "13", ",", "0"}], "}"}]},
     {"38", 
      RowBox[{"{", 
       RowBox[{"12", ",", "14", ",", "15", ",", "0"}], "}"}]},
     {"39", 
      RowBox[{"{", 
       RowBox[{"13", ",", "14", ",", "15", ",", "0"}], "}"}]},
     {"40", 
      RowBox[{"{", 
       RowBox[{"6", ",", "15", ",", "14", ",", "0"}], "}"}]},
     {"41", 
      RowBox[{"{", 
       RowBox[{"6", ",", "1", ",", "2", ",", "3"}], "}"}]},
     {"42", 
      RowBox[{"{", 
       RowBox[{"11", ",", "1", ",", "2", ",", "3"}], "}"}]},
     {"43", 
      RowBox[{"{", 
       RowBox[{"11", ",", "1", ",", "2", ",", "8"}], "}"}]},
     {"44", 
      RowBox[{"{", 
       RowBox[{"11", ",", "1", ",", "6", ",", "5"}], "}"}]},
     {"45", 
      RowBox[{"{", 
       RowBox[{"11", ",", "1", ",", "6", ",", "15"}], "}"}]},
     {"46", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "11", ",", "12"}], "}"}]},
     {"47", 
      RowBox[{"{", 
       RowBox[{"6", ",", "1", ",", "11", ",", "12"}], "}"}]},
     {"48", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}]},
     {"49", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "7"}], "}"}]},
     {"50", 
      RowBox[{"{", 
       RowBox[{"8", ",", "2", ",", "3", ",", "4"}], "}"}]},
     {"51", 
      RowBox[{"{", 
       RowBox[{"8", ",", "2", ",", "3", ",", "7"}], "}"}]},
     {"52", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "4", ",", "5"}], "}"}]},
     {"53", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "4", ",", "9"}], "}"}]},
     {"54", 
      RowBox[{"{", 
       RowBox[{"7", ",", "3", ",", "4", ",", "5"}], "}"}]},
     {"55", 
      RowBox[{"{", 
       RowBox[{"7", ",", "3", ",", "4", ",", "9"}], "}"}]},
     {"56", 
      RowBox[{"{", 
       RowBox[{"3", ",", "4", ",", "5", ",", "6"}], "}"}]},
     {"57", 
      RowBox[{"{", 
       RowBox[{"3", ",", "4", ",", "5", ",", "10"}], "}"}]},
     {"58", 
      RowBox[{"{", 
       RowBox[{"9", ",", "4", ",", "5", ",", "10"}], "}"}]},
     {"59", 
      RowBox[{"{", 
       RowBox[{"4", ",", "5", ",", "6", ",", "1"}], "}"}]},
     {"60", 
      RowBox[{"{", 
       RowBox[{"10", ",", "5", ",", "6", ",", "1"}], "}"}]},
     {"61", 
      RowBox[{"{", 
       RowBox[{"10", ",", "5", ",", "6", ",", "15"}], "}"}]},
     {"62", 
      RowBox[{"{", 
       RowBox[{"1", ",", "6", ",", "15", ",", "14"}], "}"}]},
     {"63", 
      RowBox[{"{", 
       RowBox[{"1", ",", "11", ",", "12", ",", "14"}], "}"}]},
     {"64", 
      RowBox[{"{", 
       RowBox[{"11", ",", "12", ",", "14", ",", "13"}], "}"}]},
     {"65", 
      RowBox[{"{", 
       RowBox[{"11", ",", "12", ",", "14", ",", "15"}], "}"}]},
     {"66", 
      RowBox[{"{", 
       RowBox[{"12", ",", "14", ",", "15", ",", "6"}], "}"}]},
     {"67", 
      RowBox[{"{", 
       RowBox[{"13", ",", "14", ",", "15", ",", "6"}], "}"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.442683659906685*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ab initio energies: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "398.9949421979014`"}], ",", 
     RowBox[{"-", "398.9970677112538`"}], ",", 
     RowBox[{"-", "398.9716095611223`"}], ",", 
     RowBox[{"-", "398.9717273291569`"}], ",", 
     RowBox[{"-", "398.9717287905199`"}]}], "}"}]}],
  SequenceForm[
  "Ab initio energies: ", {-398.9949421979014, -398.9970677112538, \
-398.9716095611223, -398.9717273291569, -398.9717287905199}],
  Editable->False]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.442683660014283*^9}],

Cell[BoxData["\<\"Cartesian Coordinates:\"\>"], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.4426836601396112`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "0.409239742`"}], "1.41050045`", "0.0267490207`", 
      "2.12218598`", "2.43532813`", 
      RowBox[{"-", "0.00380493274`"}], "4.21462675`", "0.8973646040000001`", 
      RowBox[{"-", "0.0340336922`"}], "3.96471852`", 
      RowBox[{"-", "1.77860362`"}], 
      RowBox[{"-", "0.0145924258`"}], "1.57340411`", 
      RowBox[{"-", "2.77379923`"}], "0.0265335594`", 
      RowBox[{"-", "0.486299791`"}], 
      RowBox[{"-", "1.22772762`"}], "0.064618185`", "6.08725905`", 
      "1.74179158`", 
      RowBox[{"-", "0.06574898430000001`"}], "2.28197168`", "4.4788729`", 
      RowBox[{"-", "0.0232647672`"}], "5.59294747`", 
      RowBox[{"-", "3.01767021`"}], 
      RowBox[{"-", "0.043987018200000005`"}], "1.18296776`", 
      RowBox[{"-", "4.78634857`"}], "0.042186740800000004`", 
      RowBox[{"-", "2.39172079`"}], "2.66903391`", "0.0309535489`", 
      RowBox[{"-", "5.18510507`"}], "0.5206077160000001`", 
      RowBox[{"-", "0.11467500100000001`"}], 
      RowBox[{"-", "7.31732371`"}], 
      RowBox[{"-", "1.20282095`"}], "0.8555334430000001`", 
      RowBox[{"-", "5.8290843`"}], 
      RowBox[{"-", "1.2064804`"}], 
      RowBox[{"-", "0.179901306`"}], 
      RowBox[{"-", "2.26635158`"}], 
      RowBox[{"-", "1.98550929`"}], "0.08410117550000001`"},
     {
      RowBox[{"-", "0.266515662`"}], "1.22317472`", "0.0122282948`", 
      "2.12698129`", "2.38165761`", "0.00488958386`", "4.25536896`", 
      "0.8472220240000001`", 
      RowBox[{"-", "0.0012648124999999999`"}], "3.95166638`", 
      RowBox[{"-", "1.78724546`"}], 
      RowBox[{"-", "0.00472823659`"}], "1.50659394`", 
      RowBox[{"-", "2.74907596`"}], "0.0035259849600000003`", 
      RowBox[{"-", "0.585053284`"}], 
      RowBox[{"-", "1.2866553`"}], "0.0154578489`", "6.12918484`", 
      "1.68652466`", 
      RowBox[{"-", "0.008362681390000001`"}], "2.24769535`", "4.42779887`", 
      "0.00196309983`", "5.5624509`", 
      RowBox[{"-", "3.05494166`"}], 
      RowBox[{"-", "0.0138171873`"}], "1.17207665`", 
      RowBox[{"-", "4.77677972`"}], 
      RowBox[{"-", "0.000457180276`"}], 
      RowBox[{"-", "2.30879772`"}], "2.73650241`", "0.0186373595`", 
      RowBox[{"-", "3.82766494`"}], "1.67979315`", 
      RowBox[{"-", "0.021380067500000002`"}], 
      RowBox[{"-", "6.9374315`"}], 
      RowBox[{"-", "1.77259648`"}], "1.11614984`", 
      RowBox[{"-", "5.86859514`"}], 
      RowBox[{"-", "1.07288156`"}], 
      RowBox[{"-", "0.17219367200000002`"}], 
      RowBox[{"-", "4.27636484`"}], 
      RowBox[{"-", "1.98657613`"}], 
      RowBox[{"-", "0.041755159300000004`"}]},
     {
      RowBox[{"-", "0.5234865540000001`"}], "1.27306525`", 
      RowBox[{"-", "0.0005954842`"}], "1.87147675`", "2.4846216`", 
      "0.0182299675`", "4.05002486`", "1.03990708`", "0.0169940867`", 
      "3.90098784`", 
      RowBox[{"-", "1.62190257`"}], "0.0033691612300000002`", "1.53099348`", 
      RowBox[{"-", "2.72047219`"}], 
      RowBox[{"-", "0.00905389838`"}], 
      RowBox[{"-", "0.595641954`"}], 
      RowBox[{"-", "1.30699107`"}], 
      RowBox[{"-", "0.00344897066`"}], "5.88312345`", "1.96625462`", 
      "0.0261460303`", "1.91875202`", "4.53358551`", "0.0230204233`", 
      "5.58062557`", 
      RowBox[{"-", "2.79381433`"}], 
      RowBox[{"-", "0.0037078631400000004`"}], "1.25780523`", 
      RowBox[{"-", "4.75464143`"}], 
      RowBox[{"-", "0.0240337574`"}], 
      RowBox[{"-", "2.64205853`"}], "2.49898916`", 
      RowBox[{"-", "0.0129996465`"}], 
      RowBox[{"-", "4.24261687`"}], "0.8718763740000001`", 
      RowBox[{"-", "0.05397646800000001`"}], 
      RowBox[{"-", "6.18339395`"}], 
      RowBox[{"-", "1.63927676`"}], "1.2642927`", 
      RowBox[{"-", "5.12791954`"}], 
      RowBox[{"-", "1.2335998`"}], 
      RowBox[{"-", "0.158965873`"}], 
      RowBox[{"-", "2.86495548`"}], 
      RowBox[{"-", "1.88947648`"}], 
      RowBox[{"-", "0.0055371180400000004`"}]},
     {
      RowBox[{"-", "0.525326143`"}], "1.27474266`", 
      RowBox[{"-", "0.000595087358`"}], "1.87175756`", "2.48471208`", 
      "0.0182488837`", "4.04978456`", "1.04053819`", "0.016992971699999998`", 
      "3.90063938`", 
      RowBox[{"-", "1.62176998`"}], "0.00338656561`", "1.5311878`", 
      RowBox[{"-", "2.72069957`"}], 
      RowBox[{"-", "0.00906370605`"}], 
      RowBox[{"-", "0.595978319`"}], 
      RowBox[{"-", "1.30689529`"}], 
      RowBox[{"-", "0.0034510304600000002`"}], "5.88301588`", "1.96666668`", 
      "0.0261526633`", "1.91817083`", "4.53364555`", "0.023039717400000003`", 
      "5.58011128`", 
      RowBox[{"-", "2.79377232`"}], 
      RowBox[{"-", "0.00369348233`"}], "1.25790866`", 
      RowBox[{"-", "4.7546693`"}], 
      RowBox[{"-", "0.0240658639`"}], 
      RowBox[{"-", "2.64101492`"}], "2.49922146`", 
      RowBox[{"-", "0.012955408100000001`"}], 
      RowBox[{"-", "4.26197349`"}], "0.845356014`", 
      RowBox[{"-", "0.052960343400000005`"}], 
      RowBox[{"-", "6.18657986`"}], 
      RowBox[{"-", "1.63394717`"}], "1.26367422`", 
      RowBox[{"-", "5.12864018`"}], 
      RowBox[{"-", "1.23266313`"}], 
      RowBox[{"-", "0.158914453`"}], 
      RowBox[{"-", "2.82982327`"}], 
      RowBox[{"-", "1.89261931`"}], 
      RowBox[{"-", "0.00684856908`"}]},
     {
      RowBox[{"-", "0.521644696`"}], "1.27138867`", 
      RowBox[{"-", "0.000595881043`"}], "1.87120067`", "2.48452758`", 
      "0.0182110514`", "4.05026709`", "1.03926825`", "0.016995201600000003`", 
      "3.9013332`", 
      RowBox[{"-", "1.62204261`"}], "0.00335175685`", "1.53079401`", 
      RowBox[{"-", "2.72024771`"}], 
      RowBox[{"-", "0.0090440907`"}], 
      RowBox[{"-", "0.595308087`"}], 
      RowBox[{"-", "1.30708575`"}], 
      RowBox[{"-", "0.00344691086`"}], "5.88323474`", "1.96583136`", 
      "0.026139397400000004`", "1.91934185`", "4.53352177`", "0.0230011292`", 
      "5.58113454`", 
      RowBox[{"-", "2.79386702`"}], 
      RowBox[{"-", "0.00372224396`"}], "1.25769276`", 
      RowBox[{"-", "4.75461596`"}], 
      RowBox[{"-", "0.024001651000000002`"}], 
      RowBox[{"-", "2.64309741`"}], "2.498762`", 
      RowBox[{"-", "0.013043885`"}], 
      RowBox[{"-", "4.2232562`"}], "0.8984030550000001`", 
      RowBox[{"-", "0.054992592699999995`"}], 
      RowBox[{"-", "6.18021165`"}], 
      RowBox[{"-", "1.64459487`"}], "1.26491119`", 
      RowBox[{"-", "5.12720135`"}], 
      RowBox[{"-", "1.23452677`"}], 
      RowBox[{"-", "0.15901729200000003`"}], 
      RowBox[{"-", "2.90009102`"}], 
      RowBox[{"-", "1.88632502`"}], 
      RowBox[{"-", "0.004225667`"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.442683660245049*^9}],

Cell[BoxData["\<\"Internal Coordinates:\"\>"], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.442683660415419*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"2.7311758463651175`", "2.6396249116290345`", "2.3482238508447475`", 
      "2.5970279091998676`", "2.0498744795904096`", "2.687682649071256`", 
      "2.0544620971321867`", "2.5904613983411506`", "2.0462843326709743`", 
      "2.575687873510628`", "2.0501318034272096`", "1.934734353297349`", 
      "3.527029702364642`", "1.8443961288084987`", "1.8130071848970002`", 
      "3.6564528926066298`", "1.9847732603729147`", "2.191262717747635`", 
      "2.1071386628449935`", "2.123153833290359`", "2.033566621437924`", 
      "2.1264023612195047`", "2.1113598635933384`", "2.084228266213693`", 
      "2.0875893672907346`", "2.058334029535558`", "2.12797147581121`", 
      "2.0968567075746902`", "2.1034548119390735`", "2.1568280633311137`", 
      "2.022885928737065`", "2.185089157921404`", "2.0025552259865664`", 
      "2.0952992562355033`", "1.9199463013947868`", "2.5837099193689106`", 
      "1.83850501581009`", "1.4270482592001141`", "2.4326066114326514`", 
      "2.5188680598708535`", "0.017534065293448007`", 
      RowBox[{"-", "3.129020175147748`"}], "0.0007660418133674618`", 
      "3.1239857176966948`", "0.006134838984756332`", "3.084514612968693`", 
      RowBox[{"-", "0.06236254871323305`"}], 
      RowBox[{"-", "0.009456522210345443`"}], "3.1364002862515967`", 
      RowBox[{"-", "3.138614041651645`"}], "0.007242766810297253`", 
      "0.003783237569860873`", "3.138077430080212`", "3.141103615156291`", 
      RowBox[{"-", "0.007787499512944281`"}], 
      RowBox[{"-", "0.007575885891514326`"}], "3.140448542874231`", 
      "0.0060189798286460405`", "0.01827787262070576`", 
      RowBox[{"-", "3.12927182423307`"}], 
      RowBox[{"-", "0.012591250702722072`"}], "0.12710684830551552`", 
      "0.016318155732775192`", "2.473895368972906`", "0.04659481761791494`", 
      RowBox[{"-", "0.1437567201174053`"}], 
      RowBox[{"-", "1.958751306586279`"}]},
     {"2.6591284516424363`", "2.5299650938189444`", "2.5418728878249945`", 
      "2.623845368535606`", "2.0497010768560497`", "2.651917452836414`", 
      "2.053208524889642`", "2.6274636590733653`", "2.049820244409514`", 
      "2.5522156385851926`", "2.0551156223513023`", "3.7575182634332362`", 
      "1.8507278261873021`", "3.4300668920077793`", "1.8143431700318298`", 
      "1.8403937896768077`", "2.1478147581160103`", "2.053105563261279`", 
      "2.0822644442344007`", "2.066179769929954`", "2.08050194818164`", 
      "2.136502857903882`", "2.0806645652996782`", "2.095841118257119`", 
      "2.106676128326536`", "2.06034459666959`", "2.122789808183382`", 
      "2.1000508928358093`", "2.156647673723794`", "2.109068143499387`", 
      "2.0174693438285485`", "2.054712206856714`", "1.8843675641436286`", 
      "2.343811077142073`", "1.8958910649024394`", "2.8160569440521885`", 
      "2.250802324096828`", "1.4510364984121655`", "1.8419816151073873`", 
      "2.431827193186328`", "0.0009015882379759228`", "3.1413663653941697`", 
      RowBox[{"-", "0.0014941728036238367`"}], "3.1392480755130197`", 
      "0.020029411594788073`", "3.1161276977030132`", 
      RowBox[{"-", "0.026548942233323877`"}], "0.0020542837312571417`", 
      "3.1408258448133193`", 
      RowBox[{"-", "3.138227414795811`"}], "0.0005441462862508088`", 
      RowBox[{"-", "0.002298401273382847`"}], "3.139146592551857`", 
      RowBox[{"-", "3.1410519765222324`"}], "0.00039301730300772417`", 
      RowBox[{"-", "0.0003725000505471333`"}], "3.140613168193379`", 
      RowBox[{"-", "0.0008338275630567328`"}], "0.003231365460630914`", 
      RowBox[{"-", "3.1377834398561855`"}], 
      RowBox[{"-", "0.025925476760774006`"}], "0.08489548435806903`", 
      RowBox[{"-", "0.06355305812383713`"}], "1.952100112860792`", 
      "0.12895944700471199`", 
      RowBox[{"-", "0.09517016236836508`"}], 
      RowBox[{"-", "2.339690071378647`"}]},
     {"2.6840403153387298`", "2.581066670682119`", "2.4477317078970473`", 
      "2.614053067419396`", "2.049514821635314`", "2.6660135567467895`", 
      "2.0538875245727795`", "2.6122562678322407`", "2.048074745105701`", 
      "2.55353452315718`", "2.0524864708632062`", "2.342878036200114`", 
      "2.2827531881498886`", "2.2864412329979227`", "1.817763733728255`", 
      "2.3610846954457356`", "2.067088786700571`", "2.1486953396212867`", 
      "2.067400705814001`", "2.0876694805272327`", "2.0622069514797015`", 
      "2.133294496842442`", "2.100426284804259`", "2.0881025802708493`", 
      "2.094656415156373`", "2.0607938048447254`", "2.1240649577077937`", 
      "2.0983210112255537`", "2.1209121790440117`", "2.138364632560432`", 
      "2.0239084885898806`", "2.1294473399711564`", "1.8500113260382154`", 
      "2.3037231927405855`", "1.8234392484378168`", "2.7616305380505155`", 
      "1.976190530186054`", "1.4522291919524482`", "2.0304529995035607`", 
      "2.6047800043226963`", "0.007071570345524838`", 
      RowBox[{"-", "3.1355860194642866`"}], "0.00037310782869484144`", 
      "3.1333322002074904`", 
      RowBox[{"-", "0.005752783694902331`"}], "3.1294294585709443`", 
      RowBox[{"-", "0.01322831119272967`"}], 
      RowBox[{"-", "0.0026913922664188222`"}], "3.138651825250299`", 
      RowBox[{"-", "3.1384124852227897`"}], "0.002930732293928126`", 
      "0.00021996937783255036`", "3.138243605557516`", 
      RowBox[{"-", "3.141122309102161`"}], 
      RowBox[{"-", "0.0030986729224777047`"}], 
      RowBox[{"-", "0.0022358634338104145`"}], "3.1392245992301664`", 
      "0.001146256783441906`", "0.006993176037841119`", 
      RowBox[{"-", "3.13447550228792`"}], "0.0038737555559436093`", 
      "0.12679688973309788`", 
      RowBox[{"-", "0.0795541719924446`"}], "2.1476688054212456`", 
      "0.126768626083338`", 
      RowBox[{"-", "0.14648159704982694`"}], 
      RowBox[{"-", "2.1116173217204803`"}]},
     {"2.6852171926621806`", "2.5826061239114146`", "2.444512243843757`", 
      "2.6133199985079676`", "2.049464688206624`", "2.6665172437193556`", 
      "2.053907240497689`", "2.6119153973677`", "2.047990594444691`", 
      "2.554155387225906`", "2.052301005129503`", "2.3093608284505533`", 
      "2.3161126902587403`", "2.253996669857162`", "1.8176973840067894`", 
      "2.396502739050075`", "2.065606044265585`", "2.1495000383486706`", 
      "2.068078740140018`", "2.0886153941619123`", "2.0609030117658875`", 
      "2.1336524556252714`", "2.100334098358134`", "2.088289061862693`", 
      "2.094562124828465`", "2.061036298186534`", "2.1241175138234563`", 
      "2.0980258939950125`", "2.1207093110639526`", "2.1386339674188415`", 
      "2.023842021894565`", "2.130036649857782`", "1.8545896729508107`", 
      "2.2985537130231726`", "1.821538659480761`", "2.7604222191507213`", 
      "1.9720019033659142`", "1.4525921997616105`", "2.0351467647954697`", 
      "2.6023913244162715`", "0.007081097941594013`", 
      RowBox[{"-", "3.1355866099154035`"}], "0.00036043405941105276`", 
      "3.133338949984397`", 
      RowBox[{"-", "0.005143468727167754`"}], "3.130136038855354`", 
      RowBox[{"-", "0.012533108574141234`"}], 
      RowBox[{"-", "0.0027191612250320033`"}], "3.13864743852179`", 
      RowBox[{"-", "3.138422229377609`"}], "0.0029443703692130967`", 
      "0.0002500779206211487`", "3.138251324768575`", 
      RowBox[{"-", "3.141115707251933`"}], 
      RowBox[{"-", "0.00311446040397936`"}], 
      RowBox[{"-", "0.002259505466813632`"}], "3.1392026953903995`", 
      "0.0011456765480590142`", "0.007008889105813907`", 
      RowBox[{"-", "3.1344614443554852`"}], "0.0031323381719036672`", 
      "0.12214423788824684`", 
      RowBox[{"-", "0.08416758540301275`"}], "2.155265921417541`", 
      "0.12941416000322323`", 
      RowBox[{"-", "0.1434690651573098`"}], 
      RowBox[{"-", "2.1044549137506383`"}]},
     {"2.6828657553540722`", "2.5795280107296708`", "2.4509512156988698`", 
      "2.614786123570034`", "2.049565248707852`", "2.665509883817563`", 
      "2.0538678679691693`", "2.6125972039387064`", "2.0481589370029623`", 
      "2.5529136649093718`", "2.0526719655049`", "2.3764559971982107`", 
      "2.249402198036953`", "2.3189065549623833`", "1.8178445644208763`", 
      "2.325687388250173`", "2.0685730011045673`", "2.1478895008997347`", 
      "2.0667223393662835`", "2.0867227704004936`", "2.063511686656474`", 
      "2.1329365388505335`", "2.100518481806385`", "2.087916112271085`", 
      "2.094750680862406`", "2.0605513350534217`", "2.1240124434317655`", 
      "2.098616062648388`", "2.1211150169159003`", "2.138095364176342`", 
      "2.023974918916198`", "2.128857349754714`", "1.8455784711006757`", 
      "2.308747444788536`", "1.825392094724726`", "2.7626985024449766`", 
      "1.980300753513108`", "1.4520226076067002`", "2.0256764238165967`", 
      "2.6069355610392133`", "0.007062075524513134`", 
      RowBox[{"-", "3.135585453826903`"}], "0.00038573681523373964`", 
      "3.13332548842776`", 
      RowBox[{"-", "0.006343641991092888`"}], "3.1287015051901093`", 
      RowBox[{"-", "0.013944966157475633`"}], 
      RowBox[{"-", "0.002663643884779629`"}], "3.138656195129641`", 
      RowBox[{"-", "3.1384027268688737`"}], "0.002917112145547064`", 
      "0.00018987094300064255`", "3.138235887376085`", 
      RowBox[{"-", "3.141128897057389`"}], 
      RowBox[{"-", "0.003082880624304618`"}], 
      RowBox[{"-", "0.002212222307537379`"}], "3.1392464983701016`", 
      "0.0011468325667609394`", "0.00697746408870639`", 
      RowBox[{"-", "3.134489554892432`"}], "0.004600746396917308`", 
      "0.13149306443301872`", 
      RowBox[{"-", "0.07491235805624792`"}], "2.140045407753269`", 
      "0.12413902114811734`", 
      RowBox[{"-", "0.14955902918302022`"}], 
      RowBox[{"-", "2.1188202096927595`"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.442683660547482*^9}],

Cell[BoxData["\<\"Internal gradients:\"\>"], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.442683660678647*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "2.98357431`*^-7"}], "1.55477457`*^-6", 
      RowBox[{"-", "2.47632528`*^-6"}], 
      RowBox[{"-", "8.33743011`*^-6"}], 
      RowBox[{"-", "9.91898671`*^-7"}], 
      RowBox[{"-", "1.52241526`*^-7"}], 
      RowBox[{"-", "5.536023819999999`*^-7"}], 
      RowBox[{"-", "5.864702109999999`*^-6"}], 
      RowBox[{"-", "1.3038567099999998`*^-7"}], 
      RowBox[{"-", "3.08194799`*^-6"}], 
      RowBox[{"-", "4.72269536`*^-7"}], "0.000014422853600000002`", 
      RowBox[{"-", "1.2656067299999999`*^-6"}], "1.8540779099999999`*^-6", 
      "8.912689359999999`*^-7", "2.40350351`*^-6", "1.19794909`*^-6", 
      RowBox[{"-", "1.17566298`*^-6"}], 
      RowBox[{"-", "1.9970853`*^-8"}], 
      RowBox[{"-", "1.3720090899999999`*^-6"}], "4.89488517`*^-7", 
      "8.83836203`*^-7", "1.63527006`*^-6", 
      RowBox[{"-", "3.7168225199999997`*^-7"}], 
      RowBox[{"-", "1.2631823099999998`*^-6"}], 
      RowBox[{"-", "1.7444645`*^-7"}], 
      RowBox[{"-", "7.234009359999999`*^-7"}], "8.964113219999999`*^-7", 
      "1.7078662099999998`*^-6", 
      RowBox[{"-", "1.0800553399999998`*^-6"}], 
      RowBox[{"-", "6.24677477`*^-7"}], 
      RowBox[{"-", "2.98637465`*^-6"}], 
      RowBox[{"-", "2.25047342`*^-6"}], "5.23316781`*^-6", "6.1681707`*^-6", 
      RowBox[{"-", "4.96334888`*^-6"}], 
      RowBox[{"-", "0.0000118430405`"}], "3.94559748`*^-6", 
      "6.501891859999999`*^-6", 
      RowBox[{"-", "3.22183419`*^-6"}], 
      RowBox[{"-", "3.66192843`*^-7"}], "1.7304662999999998`*^-7", 
      "3.0411655`*^-7", 
      RowBox[{"-", "3.66353665`*^-8"}], "7.08694731`*^-8", 
      RowBox[{"-", "2.7159087899999996`*^-6"}], 
      RowBox[{"-", "2.13872847`*^-6"}], "2.1002539100000002`*^-7", 
      "1.0250445800000001`*^-7", "7.57621584`*^-8", 
      RowBox[{"-", "3.17587752`*^-8"}], 
      RowBox[{"-", "6.58569805`*^-8"}], 
      RowBox[{"-", "2.8889391799999996`*^-7"}], "4.4040337899999996`*^-8", 
      RowBox[{"-", "1.7899659999999998`*^-7"}], "1.0939407000000001`*^-7", 
      RowBox[{"-", "4.99285692`*^-7"}], 
      RowBox[{"-", "2.73428949`*^-7"}], 
      RowBox[{"-", "3.61509587`*^-7"}], "1.99778304`*^-7", 
      RowBox[{"-", "1.4306319000000002`*^-8"}], "2.85003726`*^-6", 
      "2.5756992499999998`*^-6", "6.265683199999999`*^-6", 
      RowBox[{"-", "3.6833977799999996`*^-7"}], 
      RowBox[{"-", "2.73260087`*^-6"}], "0.0000100174945`"},
     {
      RowBox[{"-", "5.795838149999999`*^-6"}], "6.731410819999999`*^-7", 
      "0.000012773557900000003`", "7.28953951`*^-6", 
      "4.3949691099999995`*^-7", 
      RowBox[{"-", "1.48904342`*^-6"}], "2.8828711299999995`*^-7", 
      "5.3462262199999996`*^-6", "6.55051666`*^-7", "2.94142274`*^-6", 
      RowBox[{"-", "1.51213214`*^-7"}], 
      RowBox[{"-", "5.92991997`*^-6"}], 
      RowBox[{"-", "4.0202075099999996`*^-6"}], "1.82906056`*^-6", 
      RowBox[{"-", "5.05866321`*^-6"}], 
      RowBox[{"-", "2.29323487`*^-6"}], "2.19864761`*^-6", "4.09528759`*^-6", 
      
      RowBox[{"-", "6.2938658`*^-6"}], 
      RowBox[{"-", "4.8873956800000004`*^-8"}], "2.0538264599999996`*^-6", 
      RowBox[{"-", "2.0053750899999995`*^-6"}], 
      RowBox[{"-", "7.699184909999999`*^-7"}], 
      RowBox[{"-", "8.94945103`*^-7"}], "1.6646281`*^-6", 
      "5.655697889999999`*^-7", "6.227720219999999`*^-7", 
      RowBox[{"-", "1.18834306`*^-6"}], 
      RowBox[{"-", "2.06536085`*^-6"}], "1.10168019`*^-6", 
      "9.633718139999998`*^-7", "1.1966339599999998`*^-7", 
      "3.1404862599999995`*^-6", 
      RowBox[{"-", "3.3180399999999997`*^-6"}], 
      RowBox[{"-", "8.74584028`*^-6"}], "0.000014176767000000001`", 
      "2.32779078`*^-6", 
      RowBox[{"-", "9.530996289999998`*^-6"}], "2.4101808999999996`*^-6", 
      "7.15535115`*^-6", "5.35972959`*^-7", "6.04230246`*^-7", 
      "2.3631836`*^-7", 
      RowBox[{"-", "3.5928178`*^-7"}], "1.8881651199999999`*^-6", 
      RowBox[{"-", "1.8558674799999999`*^-6"}], 
      RowBox[{"-", "1.78488565`*^-6"}], 
      RowBox[{"-", "2.05261627`*^-7"}], 
      RowBox[{"-", "2.97565227`*^-7"}], "1.7197414099999998`*^-7", 
      "7.96705404`*^-8", 
      RowBox[{"-", "3.25244231`*^-7"}], 
      RowBox[{"-", "3.3503950499999997`*^-7"}], 
      RowBox[{"-", "2.28073783`*^-7"}], 
      RowBox[{"-", "2.3786905699999997`*^-7"}], "6.12901337`*^-7", 
      RowBox[{"-", "2.81848766`*^-8"}], 
      RowBox[{"-", "1.86795132`*^-8"}], 
      RowBox[{"-", "3.10344093`*^-7"}], "2.99854623`*^-7", 
      RowBox[{"-", "2.5607847899999998`*^-6"}], 
      RowBox[{"-", "1.6691370899999998`*^-7"}], 
      RowBox[{"-", "2.05589158`*^-6"}], 
      RowBox[{"-", "1.2730201199999999`*^-6"}], "3.08841653`*^-6", 
      RowBox[{"-", "5.25761286`*^-7"}], 
      RowBox[{"-", "6.35675732`*^-7"}]},
     {
      RowBox[{"-", "4.6765834299999996`*^-7"}], "8.119760550000001`*^-8", 
      "2.2579346`*^-7", "1.6167841199999999`*^-7", "3.39238063`*^-7", 
      "1.77104444`*^-7", "2.8144113599999995`*^-7", "1.19254943`*^-7", 
      RowBox[{"-", "1.27518179`*^-7"}], "7.96715983`*^-8", 
      RowBox[{"-", "1.2788129`*^-7"}], 
      RowBox[{"-", "3.17857033`*^-8"}], "7.83073313`*^-8", "1.73069855`*^-8", 
      "5.45429926`*^-8", 
      RowBox[{"-", "9.52900377`*^-9"}], "8.804810829999999`*^-8", 
      RowBox[{"-", "5.21670083`*^-8"}], 
      RowBox[{"-", "3.58676759`*^-8"}], "5.0198031500000006`*^-9", 
      "8.91794393`*^-9", 
      RowBox[{"-", "1.3898374899999999`*^-8"}], "1.4580229199999999`*^-8", 
      "5.200875950000001`*^-8", 
      RowBox[{"-", "6.65892641`*^-8"}], 
      RowBox[{"-", "5.2443692100000006`*^-8"}], 
      RowBox[{"-", "2.8829635100000003`*^-9"}], "5.52743046`*^-8", 
      RowBox[{"-", "1.18851609`*^-7"}], "1.16640128`*^-7", 
      "2.2123037600000005`*^-9", "6.37185784`*^-8", 
      RowBox[{"-", "4.03651484`*^-8"}], 
      RowBox[{"-", "2.33624312`*^-8"}], "2.06460357`*^-9", 
      RowBox[{"-", "6.28929647`*^-8"}], 
      RowBox[{"-", "4.0607736900000006`*^-8"}], "1.29786602`*^-8", 
      "2.10001023`*^-8", "1.24524362`*^-7", 
      RowBox[{"-", "1.65881202`*^-8"}], 
      RowBox[{"-", "1.5589334`*^-9"}], "6.1080212300000005`*^-9", 
      RowBox[{"-", "4.3759868500000005`*^-9"}], 
      RowBox[{"-", "1.04141229`*^-9"}], 
      RowBox[{"-", "1.0327700500000002`*^-8"}], "4.77551083`*^-9", 
      "8.35178515`*^-9", "7.06746728`*^-9", "2.81398061`*^-10", 
      RowBox[{"-", "1.0029198`*^-9"}], "6.03041117`*^-9", 
      RowBox[{"-", "1.07420969`*^-8"}], "7.3025232400000005`*^-9", 
      RowBox[{"-", "9.46998485`*^-9"}], 
      RowBox[{"-", "1.24642404`*^-8"}], 
      RowBox[{"-", "4.67519947`*^-9"}], "1.1959643600000001`*^-8", 
      "3.84990984`*^-9", 
      RowBox[{"-", "3.4641281000000003`*^-9"}], 
      RowBox[{"-", "7.74636442`*^-9"}], "1.42593541`*^-8", "1.31918401`*^-8", 
      "4.55088777`*^-9", 
      RowBox[{"-", "2.07467171`*^-8"}], 
      RowBox[{"-", "1.65838522`*^-8"}], "2.09028518`*^-8"},
     {
      RowBox[{"-", "0.000320469532`"}], 
      RowBox[{"-", "0.000593857063`"}], "0.00106769534`", 
      RowBox[{"-", "0.0000230910732`"}], "0.000023105161600000003`", 
      RowBox[{"-", "0.000340523755`"}], 
      RowBox[{"-", "3.93957281`*^-6"}], "0.00045158041400000006`", 
      "0.000018990163400000002`", 
      RowBox[{"-", "0.00007917746920000001`"}], 
      RowBox[{"-", "0.0000285041903`"}], "0.00111393334`", 
      RowBox[{"-", "0.0016281600899999999`"}], "0.00156510011`", 
      "6.18711282`*^-6", 
      RowBox[{"-", "0.00214391187`"}], "0.000693951279`", 
      RowBox[{"-", "0.0005533810730000001`"}], 
      RowBox[{"-", "0.000140559088`"}], 
      RowBox[{"-", "0.0000810248418`"}], "0.00006672291450000001`", 
      "0.000014321174000000002`", 
      RowBox[{"-", "0.000186002175`"}], "0.0000844919886`", 
      "0.00010150945499999999`", 
      RowBox[{"-", "0.0000515642734`"}], 
      RowBox[{"-", "0.000037317114200000004`"}], "0.0000888479946`", 
      "0.000295238949`", 
      RowBox[{"-", "0.000143982316`"}], 
      RowBox[{"-", "0.000151259854`"}], 
      RowBox[{"-", "0.000670373977`"}], "0.000124330634`", 
      "0.0005459250260000001`", 
      RowBox[{"-", "0.00026594387000000003`"}], "0.0000109299241`", 
      "0.000325671138`", "0.00018002635600000003`", 
      RowBox[{"-", "0.000503063138`"}], "0.00009531588100000001`", 
      RowBox[{"-", "0.0000186064989`"}], 
      RowBox[{"-", "6.31669896`*^-6"}], 
      RowBox[{"-", "2.50040965`*^-6"}], "0.000021250412700000003`", 
      "0.0000548028464`", "0.000039680823400000004`", 
      "0.000052472295200000005`", "5.942906619999999`*^-6", "2.21960888`*^-6",
       "1.8052474599999999`*^-6", 
      RowBox[{"-", "1.9180502899999998`*^-6"}], "1.6175415399999999`*^-6", 
      RowBox[{"-", "8.904345559999999`*^-6"}], "5.356645629999999`*^-6", 
      RowBox[{"-", "5.165241469999999`*^-6"}], "7.83722248`*^-6", 
      RowBox[{"-", "0.000023057771600000002`"}], 
      RowBox[{"-", "0.000012434895900000001`"}], 
      RowBox[{"-", "0.000028757945600000004`"}], "2.13239563`*^-7", 
      RowBox[{"-", "0.0000447255484`"}], 
      RowBox[{"-", "0.00012866324700000001`"}], 
      RowBox[{"-", "0.000150141482`"}], 
      RowBox[{"-", "0.00032176335200000003`"}], "0.000126903851`", 
      "0.000104978936`", 
      RowBox[{"-", "0.000309810063`"}]},
     {"0.000305930726`", "0.0005562082690000001`", 
      RowBox[{"-", "0.0010724380200000001`"}], "0.0000302157165`", 
      RowBox[{"-", "0.0000229816334`"}], "0.000333480118`", "4.56672968`*^-6",
       
      RowBox[{"-", "0.000445034643`"}], 
      RowBox[{"-", "0.0000199205672`"}], "0.00006209914320000001`", 
      "0.000027611096200000003`", 
      RowBox[{"-", "0.00146805655`"}], "0.00133823056`", 
      RowBox[{"-", "0.00181053138`"}], "0.0000333113706`", 
      "0.0019835537700000003`", 
      RowBox[{"-", "0.000692907529`"}], "0.0005856905280000001`", 
      "0.00010720686100000002`", "0.0000732777918`", 
      RowBox[{"-", "0.00006426718910000001`"}], 
      RowBox[{"-", "9.031283439999999`*^-6"}], "0.000186788958`", 
      RowBox[{"-", "0.0000845007499`"}], 
      RowBox[{"-", "0.000102287332`"}], "0.00005087653730000001`", 
      "0.00003883109660000001`", 
      RowBox[{"-", "0.0000896746252`"}], 
      RowBox[{"-", "0.000310587126`"}], "0.00015295329400000002`", 
      "0.00015763719000000002`", "0.0006923271630000001`", 
      RowBox[{"-", "0.00015606206`"}], 
      RowBox[{"-", "0.0005361878510000001`"}], "0.00022431219400000001`", 
      "0.0000118223521`", 
      RowBox[{"-", "0.000351420004`"}], 
      RowBox[{"-", "0.00010648101800000001`"}], "0.000489010003`", 
      RowBox[{"-", "0.0000853963091`"}], "0.000018628065400000003`", 
      "7.174163209999999`*^-6", "3.07664991`*^-6", 
      RowBox[{"-", "0.0000221186817`"}], 
      RowBox[{"-", "0.000057669618000000004`"}], 
      RowBox[{"-", "0.000039115098200000005`"}], 
      RowBox[{"-", "0.000051015439400000006`"}], 
      RowBox[{"-", "6.01850514`*^-6"}], 
      RowBox[{"-", "2.3264871399999996`*^-6"}], 
      RowBox[{"-", "1.5831326599999998`*^-6"}], "2.10888534`*^-6", 
      RowBox[{"-", "1.53874346`*^-6"}], "8.986735879999999`*^-6", 
      RowBox[{"-", "5.2482806`*^-6"}], "5.27719875`*^-6", 
      RowBox[{"-", "7.77040799`*^-6"}], "0.0000236027007`", 
      "0.000012970065900000002`", "0.000028666452300000004`", 
      RowBox[{"-", "7.654202069999999`*^-7"}], "0.000046593587800000005`", 
      "0.000124674409`", "0.000153689579`", "0.00033180145400000003`", 
      RowBox[{"-", "0.000131095772`"}], 
      RowBox[{"-", "0.00010351104099999999`"}], "0.00030239529100000004`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.442683660896141*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Read in \"\>", "\[InvisibleSpace]", "92", 
   "\[InvisibleSpace]", "\<\" forward and \"\>", "\[InvisibleSpace]", "93", 
   "\[InvisibleSpace]", "\<\" reverse IRC steps.\"\>"}],
  SequenceForm["Read in ", 92, " forward and ", 93, " reverse IRC steps."],
  Editable->False]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.442683662903742*^9}],

Cell[BoxData["\<\"\\!\\(\\*SubscriptBox[\\\"V\\\", \\\"11\\\"]\\)(Blue), \
\\!\\(\\*SubscriptBox[\\\"V\\\", \\\"22\\\"]\\)(Green), and Electronic Energy \
(Red) along the IRC path:\"\>"], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.4426836785827923`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.005], LineBox[CompressedData["
1:eJxFlAk01VsXwM3zHPea56Ey3StzOFtRRHhJKfO9PNUzZEg9FVEPJWUoboM5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     "]]}, 
   {RGBColor[0, 0, 1], Thickness[0.005], LineBox[CompressedData["
1:eJwViXk41HkcgMdtMJjSjFzjTJsYhMb9wYwSjQqlyDGOTTk3R2sLoZWsCjma
pxyhxTpKIo38voXM4Em1UamNImeOSMbOYNs/3ud93uc9FMXSCsHhcKI/OPS/
0SZ5uo2K3A0g+Sm6aDKSEXH5YEDUaw8gndLQuEt8hog9q7786jggHWXGKja8
Q8Ryzqsj4j1ACi/O64giI2KMkvfL5M1Aiq+8bk2WQcRwp0fX1+eBlPl3u6Pz
MiLaSDeJVRkAKSwxke03h4iUsguu3j++P0HZ+4UBUlyIoNk0BgHJsSQvlGCK
FNFZNQk6DUj6Tj4UswqkeNWm6NOVVCCRGxsGvz5Div7nbCNO9wFJnZ2Hb2Ij
RUPOzcrwj0BihMps6dNCCt+zrSdpl4FUOSsYDjRBClfftpV4U4C8PUcvrP8p
UtjRwjSP+NF9GaHGVf8g+c7fV+vfqIByomFpN/M7kvejs1trjGErfevhwzoL
iMDHM4/76IGKAv+B7lkvRMjpDsvK/Agq/7ZMMDJ4iGBwLUhn/CGojjwYG489
h+S6vPWHHVVAbbqrzPKmB5Lzp7TWt4yB+nSZQcKMLJLlDyi2b3YDikIT74bd
IpLNzdBwGD4NmqTcoc4YMSS70+g8tzATNJuiCx5k+CKZrjfDNSVC0DpUa7Ei
WY5k/FPVBLRo0BJU3K//PIDwqxarE7tNQLtaXdI6ph7h85QHOZdlQcfPVkqY
+jPC71yvnWsWAV1Vr/65PTFIuvtGuTwrEnSHx1Pd8feQdCCHWhDNBr2qyudR
Na5ISjBE+0pwgW1Jx1hJZzhIKr+k20f9A+h7ZWuXDZxBUtT98YOu22C7lbkm
7zUHSXIXPZ/+1Qs/6bQxlZW7kCQrt/bk+WrYQXYOOKddiCSEpiF1b5+AATGf
Yq+xgCTyX5gp/LkJdipxNVgps0iCGi2hedsODCmd7yqscEicJ3+9tyMbjHb5
eJa1CZE4q84iPf4XoLr/6mqccguJCV25KYGfwdhKdtte/1Iklj99VLfpJBi/
kFpWI2xBYtSL3y48CwSTcNVGffoMEuXpX7qYXgymclcGm3lMJMp6Co9zqGB6
Jzb946gkEhGG4Pz7nGCXj8f4BQ4fiRSI0z8YRIGZlF0dqvBDItQKQ9VwMpi1
TxeXj+giHG8vzUP0LphHok31WZMIx1rsHVs4BhbWLY05XnhsYzWD3DwwAxYj
kZ+yojKxDUP3fk1LY9g9lH+7xkQeWw/U5zI2woB2soxsGfYcW7t29V3DVC5Y
JlAW4i5xMGH3iFiAbwtY7RjUs/6tDBMItP4g9euCtf5WXnUDwgRGAc06tmpg
g6sYI7x3w/4NLNEqGhSCjcCLbakUh61eG51/RRgG2yklMb1biRify57ZIGuD
3ap/tG2IKLay1slkklrB/hOuqC9yDFsxsY9IMm0GSN34UjOZg30PTmPtuzUO
DtLytJQsa2y5sANM1NPBoeSIbvtAD/atV6R0an4JHGmTd1jHW7CldSCrHaSD
41DPhKzuUWzJJKky4bQnOKW1HXjf0YgtBj+KtXeUAbp5+4kVh1PY10Jh0ayb
C9AX8Vr3otnYQq+NXWzDADAejuyXLAnA5oWrbpppXHDOU6AupNZhc0Fng9br
VGBPUtquZL4M9qVHlOvr3gJ7U5PXQpjB2IxxduPjzllwuW1Sup08jk0VangU
zN+HfUtMfmvoCWxi7X7U6GQxuCU4eb4sjMfGgz0gZ7cyMBmOIvNx+7CxnpU7
9W2lcMDWqOoJwwEbrV14W8xwhoPm3PR1J8P/AJrMaZU=
     "]]}, 
   {RGBColor[0., 0.75, 0.], Thickness[0.005], LineBox[CompressedData["
1:eJwtkXlM02cAhtvachWKeCIMFVZEhbY/OQTx+F6grFjGEMwAAbceOBnKGB5Y
wdapqGwSOS0Yh04IBhyWiTqPoKgo2iqTgsNleKFYEAQRFBw9nEv2Jk+ePH+/
sRky93U0Go3xEdF/Js9l4TWalOmICbidawnjkR7dDYuhfw6iC+6PNtWVEYN8
JLSDk4SoJYn9ez1+J73m4KpvTW8RuSVMcsW7lrxUl+/ZdrwTYsaz0o69YjJA
Mev7HI8h4ubBOGcxl7zSZgubKssh+jU9ecODTDIke6ffp8jDZycvSu+3PiSv
TVvGi/MnEH7ZJT8mP5oM64xzK/jZED4+r2kpWUjelDVKh38ahNBe7By5egYZ
SVHRAy+oECZ88sk25VYyuohU8WcOIDTXUKyN3UJGLbSDR4I6EdK2vou9E+St
rnHXCetehLjG/6Vr2UHelWUoi1aJAVX93Ge2MWRMXneyWaYGOS5RPN49RMYF
Rk9uewVW5CQ/pt/4noybGsRX0w9jebhjcMv138h77eZcK38Fli1wko2OXSf/
qAOO3o6vwFKG+UEWm0YmZONHG/LmY4lR2WTpvUCMgotxHlkKBD3heE+NCyJG
0/YDVglPEThyOodl8ycxaQMfJN/WYHHnoMKfFU3Mh/peJAdfwWKO+0hEewex
yEo8F4dL4T9oz6s6MkY+COjVP+8PgD/hunnbfUU+GIv02/kD8PPLO/dIEAla
io3Ll9dq4avU30kN2QuaTtLIS/8ci8pb01IZ1aBTly6Z0nSgulaMIEMIepkL
Fd9dAoqj6unfGgW6OdvNa48X+DX6QqWbGQx515SvO4zg8QfrNguUYOiWTWfO
doP3HXZnl6Ebk6gKaXZYKhamBZ+veRWKSWpLTTHTiAWz+BpN3m5MMkscqAEm
vP7YoPJdmQim/Fq61kqIeYU7nd+LIsHUefR251DwTLTS3D20Dywqt/3CbAIu
v/WepyYBLLVBtEmwCZ+yU3BPxQfLLGr0wQm4j4QpDiVKYCWv9V3efwtzn77+
jhtVACudXT2rqABzGn6Ije3shzW10XPm0tNwa5AWMZvnwVrdWv3iVBhcb5yu
dPfwg7VZMPXltTbMenHKQFcMwEZeWH7FwoOzc+XK5m9iYKN9081P0GDGmlSG
oScJttTq1UuCWJhWt/THV1IabNVnxoqdXTGVnX52LIMHW/O0A17r3sFJOVRj
2PgL7OSZmfvj7sJx9OjW0oaHsNNqy3rs/4aDi37INakUbIp9aXNCH+xEeREz
2vzBVrtNOZeyCtbnc33qGUlgG4fqWjZNB2sWI2SfIBX20tJza5afBeMqe1fC
2o99q9DnzPqPv0v6OO6BNDjwTkW0TswmpsxqVe1rLziU9NBcfOaR975ms2gg
EQ4TTpVNZ2zJ25gd7ICm+eBI3OtaLXoynL+NK+29B85NzYeG2CjSHzrcLRMf
g6N3guGOKZ08r/LT69Ns4Vh4JPlyeDjpKjd8kRP9CI5jWRwuxSZtwg6nLv9i
TOZPW5Gzrp00Nh1ey3yYhcnxl080txXQ/t+/e7L7xw==
     "]], 
    LineBox[{{4.239148445157011, 0.}, {4.27600184, 0.0747581649190167}, {
     4.28890332, 0.02773829172020235}, {4.320887257624469, 0.}}], 
    LineBox[{{4.389249138881619, 0.}, {4.4174491, 0.039544173235359206`}, {
     4.446846277699477, 0.}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Reaction coordinate\"", TraditionalForm], 
    FormBox[
     FractionBox[
     "\"Energy\"", 
      "\"\\!\\(\\*SuperscriptBox[\\\"kJmol\\\", \\nRowBox[{\\\"-\\\", \\\"1\\\
\"}]]\\)\""], TraditionalForm]},
  AxesOrigin->{0, 0},
  ImageSize->{400, 300},
  PlotRange->{{-4.51393217, 4.45049773}, {0, 68.84036373930276}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.442683678766735*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Redundant internal distance between TS structures is \"\>", 
   "\[InvisibleSpace]", "2.018605149135508`*^-8", 
   "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "Redundant internal distance between TS structures is ", 
   2.018605149135508*^-8, "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.4426836789167767`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "67", "\[InvisibleSpace]", "\<\" internal coordinates will be used in \
fitting \\!\\(\\*SubscriptBox[\\\"V\\\", \\\"12\\\"]\\).\"\>"}],
  SequenceForm[
  67, " internal coordinates will be used in fitting \
\!\(\*SubscriptBox[\"V\", \"12\"]\)."],
  Editable->False]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.44268367892463*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "0", ",", "0"}], "}"}]},
     {"2", 
      RowBox[{"{", 
       RowBox[{"1", ",", "6", ",", "0", ",", "0"}], "}"}]},
     {"3", 
      RowBox[{"{", 
       RowBox[{"1", ",", "11", ",", "0", ",", "0"}], "}"}]},
     {"4", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "0", ",", "0"}], "}"}]},
     {"5", 
      RowBox[{"{", 
       RowBox[{"2", ",", "8", ",", "0", ",", "0"}], "}"}]},
     {"6", 
      RowBox[{"{", 
       RowBox[{"3", ",", "4", ",", "0", ",", "0"}], "}"}]},
     {"7", 
      RowBox[{"{", 
       RowBox[{"3", ",", "7", ",", "0", ",", "0"}], "}"}]},
     {"8", 
      RowBox[{"{", 
       RowBox[{"4", ",", "5", ",", "0", ",", "0"}], "}"}]},
     {"9", 
      RowBox[{"{", 
       RowBox[{"4", ",", "9", ",", "0", ",", "0"}], "}"}]},
     {"10", 
      RowBox[{"{", 
       RowBox[{"5", ",", "6", ",", "0", ",", "0"}], "}"}]},
     {"11", 
      RowBox[{"{", 
       RowBox[{"5", ",", "10", ",", "0", ",", "0"}], "}"}]},
     {"12", 
      RowBox[{"{", 
       RowBox[{"6", ",", "15", ",", "0", ",", "0"}], "}"}]},
     {"13", 
      RowBox[{"{", 
       RowBox[{"11", ",", "12", ",", "0", ",", "0"}], "}"}]},
     {"14", 
      RowBox[{"{", 
       RowBox[{"12", ",", "14", ",", "0", ",", "0"}], "}"}]},
     {"15", 
      RowBox[{"{", 
       RowBox[{"13", ",", "14", ",", "0", ",", "0"}], "}"}]},
     {"16", 
      RowBox[{"{", 
       RowBox[{"14", ",", "15", ",", "0", ",", "0"}], "}"}]},
     {"17", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "6", ",", "0"}], "}"}]},
     {"18", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "11", ",", "0"}], "}"}]},
     {"19", 
      RowBox[{"{", 
       RowBox[{"6", ",", "1", ",", "11", ",", "0"}], "}"}]},
     {"20", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "0"}], "}"}]},
     {"21", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "8", ",", "0"}], "}"}]},
     {"22", 
      RowBox[{"{", 
       RowBox[{"3", ",", "2", ",", "8", ",", "0"}], "}"}]},
     {"23", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "4", ",", "0"}], "}"}]},
     {"24", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "7", ",", "0"}], "}"}]},
     {"25", 
      RowBox[{"{", 
       RowBox[{"4", ",", "3", ",", "7", ",", "0"}], "}"}]},
     {"26", 
      RowBox[{"{", 
       RowBox[{"3", ",", "4", ",", "5", ",", "0"}], "}"}]},
     {"27", 
      RowBox[{"{", 
       RowBox[{"3", ",", "4", ",", "9", ",", "0"}], "}"}]},
     {"28", 
      RowBox[{"{", 
       RowBox[{"5", ",", "4", ",", "9", ",", "0"}], "}"}]},
     {"29", 
      RowBox[{"{", 
       RowBox[{"4", ",", "5", ",", "6", ",", "0"}], "}"}]},
     {"30", 
      RowBox[{"{", 
       RowBox[{"4", ",", "5", ",", "10", ",", "0"}], "}"}]},
     {"31", 
      RowBox[{"{", 
       RowBox[{"6", ",", "5", ",", "10", ",", "0"}], "}"}]},
     {"32", 
      RowBox[{"{", 
       RowBox[{"1", ",", "6", ",", "5", ",", "0"}], "}"}]},
     {"33", 
      RowBox[{"{", 
       RowBox[{"1", ",", "6", ",", "15", ",", "0"}], "}"}]},
     {"34", 
      RowBox[{"{", 
       RowBox[{"5", ",", "6", ",", "15", ",", "0"}], "}"}]},
     {"35", 
      RowBox[{"{", 
       RowBox[{"1", ",", "11", ",", "12", ",", "0"}], "}"}]},
     {"36", 
      RowBox[{"{", 
       RowBox[{"11", ",", "12", ",", "14", ",", "0"}], "}"}]},
     {"37", 
      RowBox[{"{", 
       RowBox[{"12", ",", "14", ",", "13", ",", "0"}], "}"}]},
     {"38", 
      RowBox[{"{", 
       RowBox[{"12", ",", "14", ",", "15", ",", "0"}], "}"}]},
     {"39", 
      RowBox[{"{", 
       RowBox[{"13", ",", "14", ",", "15", ",", "0"}], "}"}]},
     {"40", 
      RowBox[{"{", 
       RowBox[{"6", ",", "15", ",", "14", ",", "0"}], "}"}]},
     {"41", 
      RowBox[{"{", 
       RowBox[{"6", ",", "1", ",", "2", ",", "3"}], "}"}]},
     {"42", 
      RowBox[{"{", 
       RowBox[{"11", ",", "1", ",", "2", ",", "3"}], "}"}]},
     {"43", 
      RowBox[{"{", 
       RowBox[{"11", ",", "1", ",", "2", ",", "8"}], "}"}]},
     {"44", 
      RowBox[{"{", 
       RowBox[{"11", ",", "1", ",", "6", ",", "5"}], "}"}]},
     {"45", 
      RowBox[{"{", 
       RowBox[{"11", ",", "1", ",", "6", ",", "15"}], "}"}]},
     {"46", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "11", ",", "12"}], "}"}]},
     {"47", 
      RowBox[{"{", 
       RowBox[{"6", ",", "1", ",", "11", ",", "12"}], "}"}]},
     {"48", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}]},
     {"49", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "7"}], "}"}]},
     {"50", 
      RowBox[{"{", 
       RowBox[{"8", ",", "2", ",", "3", ",", "4"}], "}"}]},
     {"51", 
      RowBox[{"{", 
       RowBox[{"8", ",", "2", ",", "3", ",", "7"}], "}"}]},
     {"52", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "4", ",", "5"}], "}"}]},
     {"53", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "4", ",", "9"}], "}"}]},
     {"54", 
      RowBox[{"{", 
       RowBox[{"7", ",", "3", ",", "4", ",", "5"}], "}"}]},
     {"55", 
      RowBox[{"{", 
       RowBox[{"7", ",", "3", ",", "4", ",", "9"}], "}"}]},
     {"56", 
      RowBox[{"{", 
       RowBox[{"3", ",", "4", ",", "5", ",", "6"}], "}"}]},
     {"57", 
      RowBox[{"{", 
       RowBox[{"3", ",", "4", ",", "5", ",", "10"}], "}"}]},
     {"58", 
      RowBox[{"{", 
       RowBox[{"9", ",", "4", ",", "5", ",", "10"}], "}"}]},
     {"59", 
      RowBox[{"{", 
       RowBox[{"4", ",", "5", ",", "6", ",", "1"}], "}"}]},
     {"60", 
      RowBox[{"{", 
       RowBox[{"10", ",", "5", ",", "6", ",", "1"}], "}"}]},
     {"61", 
      RowBox[{"{", 
       RowBox[{"10", ",", "5", ",", "6", ",", "15"}], "}"}]},
     {"62", 
      RowBox[{"{", 
       RowBox[{"1", ",", "6", ",", "15", ",", "14"}], "}"}]},
     {"63", 
      RowBox[{"{", 
       RowBox[{"1", ",", "11", ",", "12", ",", "14"}], "}"}]},
     {"64", 
      RowBox[{"{", 
       RowBox[{"11", ",", "12", ",", "14", ",", "13"}], "}"}]},
     {"65", 
      RowBox[{"{", 
       RowBox[{"11", ",", "12", ",", "14", ",", "15"}], "}"}]},
     {"66", 
      RowBox[{"{", 
       RowBox[{"12", ",", "14", ",", "15", ",", "6"}], "}"}]},
     {"67", 
      RowBox[{"{", 
       RowBox[{"13", ",", "14", ",", "15", ",", "6"}], "}"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.4426836790478888`*^9}],

Cell[BoxData["\<\"Utilizing user supplied initial guess.\"\>"], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.44268368001975*^9}],

Cell[BoxData["\<\"Solving for B using GMRES.\"\>"], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.4426836800976562`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Current alpha values: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1.2`", ",", "1.3`", ",", "1.9`", ",", "1.8`", ",", "1.8`"}], 
    "}"}]}],
  SequenceForm["Current alpha values: ", {1.2, 1.3, 1.9, 1.8, 1.8}],
  Editable->False]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.442683680175003*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Norm of \\!\\(\\*SubscriptBox[\\\"r\\\", \\\"0\\\"]\\) = \"\>",
    "\[InvisibleSpace]", "5.059718329270651`*^-8", 
   "\[InvisibleSpace]", "\<\" , Dimensions: \"\>", "\[InvisibleSpace]", 
   "11730"}],
  SequenceForm[
  "Norm of \!\(\*SubscriptBox[\"r\", \"0\"]\) = ", 5.059718329270651*^-8, 
   " , Dimensions: ", 11730],
  Editable->False]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.442683687363468*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Iteration: \"\>", "\[InvisibleSpace]", "1"}],
  SequenceForm["Iteration: ", 1],
  Editable->False]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.442683687447938*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Residual: \"\>", "\[InvisibleSpace]", 
   "3.280472110537922`*^-15"}],
  SequenceForm["Residual: ", 3.280472110537922*^-15],
  Editable->False]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.442683695343439*^9}],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0, 0, 1], LineBox[{{1., 1.}, {2., 3.280472110537922*^-15}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"GMRES step\"", TraditionalForm], 
    FormBox["\"Residual\"", TraditionalForm]},
  AxesOrigin->{0, Automatic},
  ImageSize->{400, 300},
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.442683695472487*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Min element in B vector: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "2.397837752902209`"}]}],
  SequenceForm["Min element in B vector: ", -2.397837752902209],
  Editable->False]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.4426836956110697`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Max element in B vector: \"\>", "\[InvisibleSpace]", 
   "1.461164111097308`"}],
  SequenceForm["Max element in B vector: ", 1.461164111097308],
  Editable->False]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.4426836956656227`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Mean element in B vector: \"\>", "\[InvisibleSpace]", 
   "0.0005415371595259841`"}],
  SequenceForm["Mean element in B vector: ", 0.0005415371595259841],
  Editable->False]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.4426836957387877`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Norm of B vector: \"\>", "\[InvisibleSpace]", 
   "8.973162775221965`"}],
  SequenceForm["Norm of B vector: ", 8.973162775221965],
  Editable->False]], "Print",
 CellChangeTimes->{3.442683507801358*^9, 3.442683574362426*^9, 
  3.442683620176342*^9, 3.442683695829679*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["store and dump beta if necessary", "Subsection",
 ScreenStyleEnvironment->"Presentation",
 PrintingStyleEnvironment->"Presentation",
 ShowCellLabel->False,
 Magnification->1.25],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"iFigures", "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{"StoredBeta", "=", "$B"}], ";", 
      RowBox[{"PreviousnDG", "=", 
       RowBox[{"Length", "[", "$CoordDG", "]"}]}], ";"}]}], "]"}], ";"}], 
  " "}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{"iDump", "\[Equal]", "1"}], ",", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"\"\<Beta-\>\"", "<>", 
      RowBox[{"ToString", "[", 
       RowBox[{"Length", "[", "$CoordDG", "]"}], "]"}], "<>", 
      "\"\<.txt\>\""}], ",", "$B", ",", "\"\<List\>\""}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.434826997366086*^9, 3.434826997772156*^9}, {
  3.434832645621215*^9, 3.4348326511043377`*^9}}],

Cell[BoxData["\<\"Beta-5.txt\"\>"], "Output",
 CellChangeTimes->{3.437427549581724*^9, 3.4426833957164173`*^9, 
  3.442683463057234*^9, 3.4426835505078697`*^9, 3.4426836007361193`*^9, 
  3.442683641660593*^9, 3.442683697968389*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Remove", "[", "Guess", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.4348272400822906`*^9, 3.4348272466618767`*^9}, {
  3.4348326615324*^9, 3.4348326799587812`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBinUse", "[", "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Currently using \"\>", "\[InvisibleSpace]", 
   "12.371780395507812`", "\[InvisibleSpace]", "\<\" MB of memory.\"\>"}],
  SequenceForm["Currently using ", 12.371780395507812`, " MB of memory."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.4372434226615*^9, 3.437250669114625*^9, 3.4372550527865*^9, {
   3.437255092364625*^9, 3.437255172864625*^9}, 3.4373276462333317`*^9, 
   3.437331096889311*^9, 3.437395755568035*^9, 3.437399070093008*^9, 
   3.4373991289389772`*^9, 3.437408668496966*^9, 3.43741294894648*^9, 
   3.437413365178754*^9, 3.437413420475841*^9, 3.437427549950499*^9, 
   3.442683396150115*^9, 3.442683463638796*^9, 3.44268355083181*^9, 
   3.442683601129816*^9, 3.44268364205884*^9, 3.442683698525016*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Analyze the EVB Fit", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"First", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Simplify", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"V", "\[Equal]", " ", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["V", "11"], "+", 
             SubscriptBox["V", "22"]}], ")"}]}], "-", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               FractionBox["1", "2"], "*", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["V", "11"], "-", 
                 SubscriptBox["V", "22"]}], ")"}]}], ")"}], "2"], "+", "x"}], 
           "]"}]}]}], ",", "x"}], "]"}], "]"}], "/.", 
     RowBox[{"x", "\[Rule]", 
      SuperscriptBox[
       SubscriptBox["V", "12"], "2"]}]}], "]"}], "]"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.437339186173005*^9, 3.4373391883843307`*^9}}],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["V", "12", "2"], "\[Rule]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"V", "-", 
     SubscriptBox["V", "11"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"V", "-", 
     SubscriptBox["V", "22"]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.43733918935921*^9, 3.437395831965209*^9, 
  3.437399139035681*^9, 3.437408676019188*^9, 3.437412949097754*^9, 
  3.437413365350039*^9, 3.437413420629324*^9, 3.43742755664458*^9, 
  3.44268379165024*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "AnalyzeEVBfit", "]"}]], "Input",
 CellChangeTimes->{{3.4374077555659847`*^9, 3.4374077635091677`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"AngleAnalysis", "\[Rule]", "False"}], ",", 
   RowBox[{"DecomposeV12", "\[Rule]", "False"}], ",", 
   RowBox[{"GradientNorm", "\[Rule]", "True"}], ",", 
   RowBox[{"HessianNorm", "\[Rule]", "False"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"400", ",", "300"}], "}"}]}], ",", 
   RowBox[{"V12Analysis", "\[Rule]", "True"}]}], "}"}]], "Output",
 CellChangeTimes->{3.43740776394527*^9, 3.437408677374529*^9, 
  3.437412949309499*^9, 3.437413365563484*^9, 3.437413420745775*^9, 
  3.437427557050962*^9, 3.442683792047051*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "AnalyzeEVBfit"}]], "Input",
 CellChangeTimes->{{3.437407731305887*^9, 3.4374077535814247`*^9}, 
   3.437408693896212*^9}],

Cell[BoxData[
 StyleBox["\<\"AnalyzeEVBfit[B,IRCgeom,RxCoord,AtomicMass] analyzes the EVB \
fit along the IRC utilizing the current EVB global variables. AtomicMass is \
an optional argument containing the atomic mass for each atom in the system. \
AtomicMass is only required when AngleAnalysis is enabled. B, IRCgeom, and \
RxCoord default to $B, $IntPath, and $RxcoordPath respectively if no \
arguments or only AtomicMass is provided.\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.4426837925108633`*^9},
 CellTags->"Info3442665792-3485601"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AnalyzeEVBfit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.437333218794162*^9, 3.437333243521221*^9}, 
   3.4373336072593727`*^9, {3.437343985992947*^9, 3.4373439909852333`*^9}, 
   3.437345102779917*^9, {3.43739858081579*^9, 3.437398585274695*^9}, {
   3.437400086478726*^9, 3.4374000901734667`*^9}, {3.437400281224248*^9, 
   3.437400289291956*^9}, {3.437406880411166*^9, 3.437406882449649*^9}, 
   3.437407729403167*^9, 3.437412622457279*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reaction barrier: \"\>", "\[InvisibleSpace]", 
   "66.84036373930276`", "\[InvisibleSpace]", "\<\" kJ/mol\"\>"}],
  SequenceForm["Reaction barrier: ", 66.84036373930276, " kJ/mol"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374275581310663`*^9, 3.442683792865383*^9}],

Cell[BoxData["\<\"Energies along the IRC:\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374275581310663`*^9, 3.442684267428693*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.005], LineBox[CompressedData["
1:eJxFlAk01VsXwM3zHPea56Ey3StzOFtRRHhJKfO9PNUzZEg9FVEPJWUoboM5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     "]]}, 
   {RGBColor[0, 0, 1], Thickness[0.005], LineBox[CompressedData["
1:eJwViXk41HkcgMdtMJjSjFzjTJsYhMb9wYwSjQqlyDGOTTk3R2sLoZWsCjma
pxyhxTpKIo38voXM4Em1UamNImeOSMbOYNs/3ud93uc9FMXSCsHhcKI/OPS/
0SZ5uo2K3A0g+Sm6aDKSEXH5YEDUaw8gndLQuEt8hog9q7786jggHWXGKja8
Q8Ryzqsj4j1ACi/O64giI2KMkvfL5M1Aiq+8bk2WQcRwp0fX1+eBlPl3u6Pz
MiLaSDeJVRkAKSwxke03h4iUsguu3j++P0HZ+4UBUlyIoNk0BgHJsSQvlGCK
FNFZNQk6DUj6Tj4UswqkeNWm6NOVVCCRGxsGvz5Div7nbCNO9wFJnZ2Hb2Ij
RUPOzcrwj0BihMps6dNCCt+zrSdpl4FUOSsYDjRBClfftpV4U4C8PUcvrP8p
UtjRwjSP+NF9GaHGVf8g+c7fV+vfqIByomFpN/M7kvejs1trjGErfevhwzoL
iMDHM4/76IGKAv+B7lkvRMjpDsvK/Agq/7ZMMDJ4iGBwLUhn/CGojjwYG489
h+S6vPWHHVVAbbqrzPKmB5Lzp7TWt4yB+nSZQcKMLJLlDyi2b3YDikIT74bd
IpLNzdBwGD4NmqTcoc4YMSS70+g8tzATNJuiCx5k+CKZrjfDNSVC0DpUa7Ei
WY5k/FPVBLRo0BJU3K//PIDwqxarE7tNQLtaXdI6ph7h85QHOZdlQcfPVkqY
+jPC71yvnWsWAV1Vr/65PTFIuvtGuTwrEnSHx1Pd8feQdCCHWhDNBr2qyudR
Na5ISjBE+0pwgW1Jx1hJZzhIKr+k20f9A+h7ZWuXDZxBUtT98YOu22C7lbkm
7zUHSXIXPZ/+1Qs/6bQxlZW7kCQrt/bk+WrYQXYOOKddiCSEpiF1b5+AATGf
Yq+xgCTyX5gp/LkJdipxNVgps0iCGi2hedsODCmd7yqscEicJ3+9tyMbjHb5
eJa1CZE4q84iPf4XoLr/6mqccguJCV25KYGfwdhKdtte/1Iklj99VLfpJBi/
kFpWI2xBYtSL3y48CwSTcNVGffoMEuXpX7qYXgymclcGm3lMJMp6Co9zqGB6
Jzb946gkEhGG4Pz7nGCXj8f4BQ4fiRSI0z8YRIGZlF0dqvBDItQKQ9VwMpi1
TxeXj+giHG8vzUP0LphHok31WZMIx1rsHVs4BhbWLY05XnhsYzWD3DwwAxYj
kZ+yojKxDUP3fk1LY9g9lH+7xkQeWw/U5zI2woB2soxsGfYcW7t29V3DVC5Y
JlAW4i5xMGH3iFiAbwtY7RjUs/6tDBMItP4g9euCtf5WXnUDwgRGAc06tmpg
g6sYI7x3w/4NLNEqGhSCjcCLbakUh61eG51/RRgG2yklMb1biRify57ZIGuD
3ap/tG2IKLay1slkklrB/hOuqC9yDFsxsY9IMm0GSN34UjOZg30PTmPtuzUO
DtLytJQsa2y5sANM1NPBoeSIbvtAD/atV6R0an4JHGmTd1jHW7CldSCrHaSD
41DPhKzuUWzJJKky4bQnOKW1HXjf0YgtBj+KtXeUAbp5+4kVh1PY10Jh0ayb
C9AX8Vr3otnYQq+NXWzDADAejuyXLAnA5oWrbpppXHDOU6AupNZhc0Fng9br
VGBPUtquZL4M9qVHlOvr3gJ7U5PXQpjB2IxxduPjzllwuW1Sup08jk0VangU
zN+HfUtMfmvoCWxi7X7U6GQxuCU4eb4sjMfGgz0gZ7cyMBmOIvNx+7CxnpU7
9W2lcMDWqOoJwwEbrV14W8xwhoPm3PR1J8P/AJrMaZU=
     "]]}, 
   {RGBColor[0., 0.75, 0.], Thickness[0.005], LineBox[CompressedData["
1:eJwtkXlM02cAhtvachWKeCIMFVZEhbY/OQTx+F6grFjGEMwAAbceOBnKGB5Y
wdapqGwSOS0Yh04IBhyWiTqPoKgo2iqTgsNleKFYEAQRFBw9nEv2Jk+ePH+/
sRky93U0Go3xEdF/Js9l4TWalOmICbidawnjkR7dDYuhfw6iC+6PNtWVEYN8
JLSDk4SoJYn9ez1+J73m4KpvTW8RuSVMcsW7lrxUl+/ZdrwTYsaz0o69YjJA
Mev7HI8h4ubBOGcxl7zSZgubKssh+jU9ecODTDIke6ffp8jDZycvSu+3PiSv
TVvGi/MnEH7ZJT8mP5oM64xzK/jZED4+r2kpWUjelDVKh38ahNBe7By5egYZ
SVHRAy+oECZ88sk25VYyuohU8WcOIDTXUKyN3UJGLbSDR4I6EdK2vou9E+St
rnHXCetehLjG/6Vr2UHelWUoi1aJAVX93Ge2MWRMXneyWaYGOS5RPN49RMYF
Rk9uewVW5CQ/pt/4noybGsRX0w9jebhjcMv138h77eZcK38Fli1wko2OXSf/
qAOO3o6vwFKG+UEWm0YmZONHG/LmY4lR2WTpvUCMgotxHlkKBD3heE+NCyJG
0/YDVglPEThyOodl8ycxaQMfJN/WYHHnoMKfFU3Mh/peJAdfwWKO+0hEewex
yEo8F4dL4T9oz6s6MkY+COjVP+8PgD/hunnbfUU+GIv02/kD8PPLO/dIEAla
io3Ll9dq4avU30kN2QuaTtLIS/8ci8pb01IZ1aBTly6Z0nSgulaMIEMIepkL
Fd9dAoqj6unfGgW6OdvNa48X+DX6QqWbGQx515SvO4zg8QfrNguUYOiWTWfO
doP3HXZnl6Ebk6gKaXZYKhamBZ+veRWKSWpLTTHTiAWz+BpN3m5MMkscqAEm
vP7YoPJdmQim/Fq61kqIeYU7nd+LIsHUefR251DwTLTS3D20Dywqt/3CbAIu
v/WepyYBLLVBtEmwCZ+yU3BPxQfLLGr0wQm4j4QpDiVKYCWv9V3efwtzn77+
jhtVACudXT2rqABzGn6Ije3shzW10XPm0tNwa5AWMZvnwVrdWv3iVBhcb5yu
dPfwg7VZMPXltTbMenHKQFcMwEZeWH7FwoOzc+XK5m9iYKN9081P0GDGmlSG
oScJttTq1UuCWJhWt/THV1IabNVnxoqdXTGVnX52LIMHW/O0A17r3sFJOVRj
2PgL7OSZmfvj7sJx9OjW0oaHsNNqy3rs/4aDi37INakUbIp9aXNCH+xEeREz
2vzBVrtNOZeyCtbnc33qGUlgG4fqWjZNB2sWI2SfIBX20tJza5afBeMqe1fC
2o99q9DnzPqPv0v6OO6BNDjwTkW0TswmpsxqVe1rLziU9NBcfOaR975ms2gg
EQ4TTpVNZ2zJ25gd7ICm+eBI3OtaLXoynL+NK+29B85NzYeG2CjSHzrcLRMf
g6N3guGOKZ08r/LT69Ns4Vh4JPlyeDjpKjd8kRP9CI5jWRwuxSZtwg6nLv9i
TOZPW5Gzrp00Nh1ey3yYhcnxl080txXQ/t+/e7L7xw==
     "]], 
    LineBox[{{4.239148445157011, 0.}, {4.27600184, 0.0747581649190167}, {
     4.28890332, 0.02773829172020235}, {4.320887257624469, 0.}}], 
    LineBox[{{4.389249138881619, 0.}, {4.4174491, 0.039544173235359206`}, {
     4.446846277699477, 0.}}]}, 
   {GrayLevel[0], Thickness[0.004], LineBox[CompressedData["
1:eJxFU3k01HsfnjGDKc1gENmX5CLNkLXk+8F0FULXLZUWRq7ycgltSAlptcZM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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Reaction coordinate\"", TraditionalForm], 
    FormBox[
     FractionBox[
     "\"Energy\"", 
      "\"\\!\\(\\*SuperscriptBox[\\\"kJmol\\\", \\nRowBox[{\\\"-\\\", \\\"1\\\
\"}]]\\)\""], TraditionalForm]},
  AxesOrigin->{0, 0},
  ImageSize->{400, 300},
  PlotRange->{{-4.51393217, 4.45049773}, {0, 68.84036373930276}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374275581310663`*^9, 3.4426842676211853`*^9}],

Cell[BoxData["\<\"Red = IRC, Blue = \\!\\(\\*SubscriptBox[\\\"V\\\", \\\"11\\\
\"]\\), Green = \\!\\(\\*SubscriptBox[\\\"V\\\", \\\"22\\\"]\\), Black = \
EVB\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374275581310663`*^9, 3.44268426775521*^9}],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374275581310663`*^9, 3.44268426785281*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Maximum energy error along the IRC: \"\>", "\[InvisibleSpace]",
    "2.3749669039726067`", "\[InvisibleSpace]", "\<\" kJ/mol\"\>"}],
  SequenceForm[
  "Maximum energy error along the IRC: ", 2.3749669039726067`, " kJ/mol"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374275581310663`*^9, 3.442684267960956*^9}],

Cell[BoxData["\<\"Energy error along the IRC:\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374275581310663`*^9, 3.442684268061448*^9}],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.6, 0.4, 0.2], Thickness[0.005], LineBox[CompressedData["
1:eJwtlXk0FOobx2fGbjAzVMraJmUdrhil3teWorRQ3FIZS/3qcq1X2nSp0HLL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    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Reaction coordinate\"", TraditionalForm], 
    FormBox[
     FractionBox[
     "\"Energy\"", 
      "\"\\!\\(\\*SuperscriptBox[\\\"kJmol\\\", \\nRowBox[{\\\"-\\\", \\\"1\\\
\"}]]\\)\""], TraditionalForm]},
  ImageSize->{400, 300},
  PlotRange->{-2.3749669039726067`, 2.3749669039726067`},
  PlotRangeClipping->True]], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374275581310663`*^9, 3.442684268225288*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData["\<\"\\!\\(\\*SuperscriptBox[SubscriptBox[\\\"V\\\", \
\\\"12\\\"], \\\"2\\\"]\\) along the IRC:\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374275581310663`*^9, 3.442684268392928*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0.5, 0], Thickness[0.005], LineBox[CompressedData["
1:eJwBcQWO+lJvYiFlAAAAAgAAAFYAAAACwBIORDwaDJw+2gpkJHhZysAR9VFg
b9dTPukzsAiplZrAEcr5XPipdT7Nspx5FFYFwBGju9RXBMq+wpzfNIFSLsAR
cRRY0n8TPvNdyLaSoIjAEWxDvZn+7z7+mUBkJTUdwBE8CLQDqCs+50b+r+IX
V8ARH6GFS1jvPtYKGfo2DaDAEPBtODyyY77mer2WIwsSwBDAfBwFRDi+/QD7
0FrOjsAQkDyY4o+CvwPpEem/fHHAEF99PW1zzL8C8iUeRXMOwBAtu52lbOG+
79mVeAyQPcAP9o076DiOPwK+taRyIvTAD5DZvJ9YHz8aqOHzISCYwA8qt041
bR8/J8kQlQoQacAOxIb5rtgaPzEpgiqTOHTADl5EmrmqMD83ABhjkij5wA34
CU5dWyU/PICvQ8p8oMANkcdpi4nhP0FPB/FFThbADSuUYyPmuj9EFvJmm0kP
wAzFWCffQho/RzGrn/lSDcAMXx+5rrfkP0n82k8HzWDAC/jVEL4TTD9ND2nq
4XFgwAuShx5B33M/T9MUDRbMCcALLC6ByJeJP1FrXuvoWh3ACsXY36qf/D9S
ywno+M2jwApfghz7OHA/VDRkKogUYMAJ+Tb55zcxP1WQFy5v/ETACZMY1ruO
Cz9W6s3ZWa3twAks/qzutgE/WELzHu4yIMAIx5yjDmJuP1mU+LIMo7bACGG7
L5Zwmj9a24yektYOwAf72jjxDUk/XCzApK/OLsAHlZ/HWx3eP11ibVUf6I3A
By9NdtZLJj9enkHWSoGdwAbI8lTGq8s/X8pY81Mq/8AGYpKsaoGpP2B4sAr0
B8XABfwyZa3Zwj9hB0n4R9FPwAWV0TQPpxI/YZQCp25Jq8AFL3AFIKY+P2IY
0uyr+7zABMkOmcvDjT9im21OjOblwARirTaEdnI/Yxl/YBU81cAD/EvIgGHl
P2OTFyoI4BfAA5XqWSS0aj9kBzCq4erYwAMviPSFzmE/ZHaY1dKNYsACySeK
iISeP2TiUBzY71DAAmLGQMGRLz9lR/tgBRbvwAH8ZQBfzEM/ZaurYZJmssAB
lgRE3itvP2YEOTCEIwzAAS+kLRtsFz9mZTyTZA5NwADJSDhTArE/ZqTDO9GE
ssAAYvLL5PBaP2cS80p2HRu///mHF7bV6z9nHEnCFZ8Hv/8tT88gOTA/Z8aP
tCVdnL/+YSfIRf9pP2eOVQ/u+KS//ZSQ26/pkj9oPPSgs7NWv/zH4ANgXLc/
aCse5TMAKr/7+yGMFs8kP2iQIp6NxdC/+y5gtiM9HD9oo4KIIo8Qv/phnyGY
1vw/aOESa4QOqL/5lOPv1A3fP2j1LkAeqG+/+Mia6/8XIj9pN0akXm5sv/f9
xE5OFrk/aRkrLZD217/3MT9tfjK2P2mGaHlIM8q/9mSDYkqi5j9phifNS+Gc
v/WXw0AxHYQ/abGbH6+cNL/0ywGg6e/zP2nLVhOUfqm/8/5AFxxRRD9p6zYd
MZ2Nv/MxfqV3c1Q/agm3s2jHeb/yZL10P0IKP2oumOUlEAy/8Zf8mO1MST9q
WcUAhKKVv/DLPD50r9U/ao5pN+sx/r/v/PlMIIPIP2rURdwPi66/7mN8Y/6t
Gj9rMH7uZMFFv+zKAshcT7c/a6wLF/YnHr/rMI2ywcTtP2xRFU9S2VO/6Zce
U5bvtT9tMERScXOSv+f9tW/j6J4/bllVWyYjjb/mZFNAkTcYP2/nlbnyalS/
5Mr3sK68oD9w/jWIiM2+v+MxoUDpD4o/cmXCPsenob/hmEnLrp0/P3RCS23Y
zEK/3/3RG+bmVD92nPSFxvBCv9zK9OLi2yQ/eWluPKMq5r/a15jPNNjbP3tT
DZ+jrv64FJ4b
     "]], LineBox[CompressedData["
1:eJwVymk4FHgcwPEZDGEwI1KOIZEOzCgiZX7/1pVjVc5JjjkZxyiVXJvdUpSj
XDtUhISUo6hWVuOszFhr6aFD+0hyl0QRM6NtX3yfz5uv51HmRg4Gg5H5kc//
wlDNGWFsihASvVSKy2pX4U03PiXpsTckbLAdoOlyYVi6uJQ06gynXvYbDLKq
YKQgKJWi0wgncXXDzfvPwqhFyc6Q+60Q/aRzN21iO7wXda6OT+vDMdNjl2QE
vTDOmv/pueoRiDpQbWApjYMJqW1ZmOQL8JS7L5ICr8AUvyA5tnQQIq0WblJJ
cTBDkaubVCuGiNLo3so5f/ggTHBouVEAEZbODna/RcEs82tfStwFCH9nfZeb
lgafJCeXcjJWILwUqsfK/WBOJDYoMk+A8MjNDa1uqvA5v5kxl/YRwu3YE2xD
b5hnJ2GtG5MgXLPR1ZkvAwsWUGauNQNhM+9IVFwhLKxiLl2zGYSwbnqMfhYJ
voiaz1QoTEBY3vSXj7xC+Jp/9HT2QVcI+9WZVx8kgUVW9e0OJh/CLDPmll2E
sEQWGxv1F0HYlpOCyrYoWJLUu7byrgB3CcsrqQD4JjxxTt4yDrivVOQn3tjB
Mt/qepdfEXCLNp47mukFK8yl6/UXtgA3yUiNdlYOxORHvoanfvzmvQNpSWQQ
S+LT5WlvgaubsHz/1iRIhNYvArpqIfRO5Tpdj60g/X1yLMBWAKENnUf6rNbC
KjPXeJcjA0I1M03tE0rhOxlbXphqBaHkyMG8CgJ8F2f3xZvPQEi+YcRZdy2E
Ya/R9mmrgpDUh8sGhU4II6I3m/HcIURT65r1Eg1hKU1NknARcIb6MHt80xA2
X5viN5ILnNhws7ZnGxBWmqBnkmwCHBPDOs8MVyTDGlIPfi4Gdsdtb5Xme0hG
tFdTjqQH7BCFzSJoQLKUIkaCPRdY0j1mDsUMJMtfvZUjJwZW/utp20QWkpXS
VSgzcsDawspSHf2G5FhtPKG8AzAf+X9wKHRDciLDiZFECjDtVbkZdA+Eo5zr
byQBMLrjaVNZzQjHH3c+Tj4ODI8unpZGDMJJnZtNUQXQe6rwL6v3I3lW1Q67
6WdAd3EOsZnTQfIipTpc9mUITuZcPN9/GSlQIo219tyDIN72fWkGFkiB31M+
VmMPgQc4NqRMMlKQktdOtf0DAVsrV749V0ZrWFkFglUzOILRSA8tiERrhJ9H
zGm1cLjnUO2A4hhSpHh57bbBAY0/jOucf4UU+Q2LOet1wM9Hr4dOtEeKUo10
E85X8CXGHArKHkdKrOjoVN+/wLt9cFvUfBRSEgrz3+Nfg1e8aiqjGI+UKcpN
J2iT4KldMtvEISBlvp76A/ZBODjQJSknnUbK4tnqp8c1wePv8OWQrcsIz8h7
cNjuPrjvDGT8+9IY4Z9lmTaEuoELm5LhmRyDVMxq9veskMCpiaJgSb2NVHLf
Y7RNN4P9lK1m+/IupLJCvNHSoAj7djDixBGHkSp9Y3XPah/s7QvJ4k1cRapP
ar/Xe/4M1hc67PKnfkFq22nj3RIe7Fivrcl+nIzUsq4FPHZ0hG36LukpV78h
tcVTqkYUZdB/wG6PpdcigrkGNZHTD3h1O06NNhUR6B0KlWt9BJ+GFY3l590Q
IVvJNeXhVAt2kppJIY4iQhVJ/fLNshbZHP+V2LYoRHiVxpi1KBWMVL3QaUn/
ExGmnGzdsVaCGX7uTHmFLyJql+z+LHABmRL8Xa4uAxFNBh0LIwOpH/hGPo82
RSKiP37Iv26TYCz4D4fB1QJETHThBXi8FXxi1F/RaT2PiHdin75dOUNd8Jxe
7q3KQ8SeA05j654K2pnBclam+P8AOidngQ==
     "]]}, 
   {GrayLevel[0], Thickness[0.004], LineBox[CompressedData["
1:eJwV0nk0lHsYB/DXnp1SSkPcdLmRpWuZTvJMpdNCzBhqyjpjeKlEiHNv3bzt
KYpkmxRRsk5XJ1Sq95d1mEqLQRuRSAnZMgzue/94znM+53u+5zx/PJ4RPJNg
DMPkqdn1/0YLtVycDDSygXVQKmgxQUh3ghUY0c4G1oeUHvullJulvlNFh4Fl
j02XVGFIN7+6dbdiMzCDWIlDb6j8kB7ndfwiYAntOfX2VH5g8+OsuWHwVO54
1HCcQLpOC+4pFFoAy3WXZcVHyitunHblDAOLns7/tZ5AOiPhdKe7QcBMOHL4
Unwu0kFHaUoudGDS8SO6TZSTnTJ7Lp0AjwibT/KLMaQT8M+G8Ohn4LHFjqaa
R/XXVF+7daAbPMxH2eYMBtKeTFr/lX4RPPpr5gtolJPfPsrhrACmRxy/4Cjl
1VXu9uGUf6pMVnpiSKvujFTYYQCs6MDVYwGU/V0ED4ptwNPRo7ZVg0CaU6ru
fj6rwLP5SXlOGOWUxrALCd3ALtUONtRESNPiStDKvofgtUXDvFERIY16jlnX
JgPwZlTF7flGII2AFQ+EVb3g3VXXv0pCIPUpic6TRW6wq7c4/oQRhtQvnzXa
2BUNu7N2ykf5IqRuaXVclJEAnDSlrGgcQ2r1HV3FOTLYwx8orN6EkFrACdoM
PRL2skcMXggYSFXqIO13tAWf9RobspMQUk1d2lZ9UR18l0db4iUEUrWcKx2q
lAO/ZT4KQ7cZaEFjdr4W7yD4jXF/JHZS5lZbp0cKwH+aOTNTQyCVmXf0n5rb
IeCbqPN5KoZU0nIafQw7ITA8xe4MCyEV652xba6/Q+AXnZJUVQIpi0a9GkrE
wN2rUiKxYiBl3uXSfceLgPvc0OHvFoSUZGuDy97WAM/5Pn8r9T9Kaa/stG8v
BF5p39nmOMrWkUrGBc4QtCz7YMdLDCk2aWWJa5Mg6Pg9WVIHQoq8ModTsVEQ
9JUtiypHSEHmKiK4X4C/7b0eYx2GFNK+7TG9tw/4hXlu65iUrc+Nn37BBf58
HbtuB0LyTWbnz526DsGcL7VaNxlIntfAeJpiDcH5hYqDLxGSkwVjAc82Q/BU
zzOBGENy6YounRYREGLdFldDUra+uWb5AX0IuTA2W3AMIaxpG50tXw4haX3e
Gocp80bFvSN7ATeJaWfWMMh56Vn9Ssl3CCl9N82+j8j5NR4txutsAH/DvyPi
YeQc10y0ZT4MQhoGNzIbCXL2SvL7OwOXAZ/8I1UllCBljZ8UAn2rAPfdGltz
HyNnZkwSl7SYAt6bqzf+mrJVYOXKDTTAy6898RZh5DQ3xySzTQb4gOClYyJG
Sq98Hm7V7AK8PgT2XyXIKZHg+7z+bxC6GI93TcXIX7N17u5LHgDOdOhSm6Ns
C+HH1lZCKE1nVFGZICf5J3k78voAR68uTGAEOZFRy7A1PAV4D130Zw1Gjovl
cgeGxwBv25o8PEGQY3MMfRrLBfAPZZIoPYwcsz12Ky7aC/Buu6vCPIwc5T+O
gU1qgA9xsnN2YOTPDFnmD7ftEKowGfcxCSNHxE7OMXckEGoWx7SREOSwTOpm
fFIEoX7tCbQejBwKOho0V2YAoUJJu1UjRg42y4t8PaogzJSJZA8x8rtN0t2n
dT8gTJyg1UXdN5BhxE4froB9FYIB8yaM7J+tiPj89Trsn2rNFJ8hyD4+m5Hi
uBTC756MKWomyN7mX/8KH+VCpJLFoHMLIj/b3mAMaJ+HQ5lRTdm1xmR35nax
8BpAdIF/sXh/Ltk1+2p5X58XxNoU8aLlEfmhebyn570p/LXKyaYmn0G+K3A2
UvRXgiNszZx84dx/TsWhjg==
     "]], LineBox[CompressedData["
1:eJwV0Hk0lXkYB/DXvi83kkOMFqORuJoQxfOrXCSjcq8sXbmL+75a7igcwoxz
i5HRnLHVpUmWlJDl2BoZ8lLJvY1SnalmdAZlJyVb3KV554/nPOdznu9zznOe
oBjeBgGGYapUBf/fYSDxUOClvHhIYRqUlNcp4c1j/YzUDhYkPT2VVR87D4OK
peXUd76QwD5Y5+a2HYYLj12gW7ZCnK//jvK8InjnXPot3kzC6fb0zoOvSBiR
PlCOTX0Fwj/cMNNv+mGM/2nvC8OjcHJ/a+1cLQfGFR7lx+ULcLwn9czKIAaT
4sK0xLKXEN1/x4cXIYJpunr9hFEJRDuNCX5oJGFGkuzdeb0QiAeCfG0Oglne
4rOMs5lApHhuKvMRwQd5/HLeL6tA+LVm3VBB8FEqs7nmmAyE7fokszIS5gra
uR+z3gOh717N+BeDT1GpKm6tqYCvpO2KtMRg3hnKHddNA/5h/e2ZGyTMK7Ff
r+58CfhQetAJBgkL0vZzFVrjgE+07oiIF8FiQcyPuYf8AW90Y90tQ7DEr6m+
zxNT+fV7GEYIlp1ktpufXwN8rDJvtz0Gy/JGf1J4hdoPedygI4LPkrh0zR1n
gdAx1D1vTMKK2KW4N4TKL86aK1dEsMpbLm7M3AKEQ47GFgIDmdPdIxsTzgKu
8F6XZIZAJk+6qBk6BASnu+KchQjkErdX7N46wGc/6XANSFBcnhhle9wDotJg
2HQVAyUv39aVwQW8//YDvzci+OKkcrPoggsQ0uqwrhMYfJHlPktynAZCdSbH
hCNCWJS2RXBXFRAVNPH1ZcpSTvs2YQAQ3nvZOfMipEJva5OfkAKRdnEpyIJy
gQU9ZDgfiMPd2tXulBXJVnZpdtR9h3f+/BNCqvyBNZEvZEDsshosPE4iVenu
terWVkDQw+73nkdIjX6Nm7wvmvpHduDl7SKkJlZW5qnLAH8ft7u4l0RqCo4B
fVod8M7AsJRMEqnzu4QSTW/ALz3SLXKlLN04PpxCB5w9tSrvxpAGPf15qzUA
bnt0ZWs1iTTEY76xTrEgePtZMtYsQhoK33YHVAGCEp6W+WkSafKrtntOPQJB
UOJSgCaGNKW69Rq52SBQe033ShQhLfop23W7GiCq5p3jLQWJtMR9N0dr90EU
Kyy/dAtCWgonk8mufuAv2Fwp9iGRNj+n8J5yG/DzlGYm5jZIWzI37BhaB3z7
ky3a7STSoTOZ7js1gNft+WGDKmVx01KeuSXwghw1HjYNIR2F6UU7wSJwR8aT
3Q5gSJd/5syFI38CV3i3ZaAJIV2JpGBE/x/gKK2z6sIR0qPrtcWFTgAn1WOm
TYNEemKrNS1Rh4BDIyMCFjCkJ5ut6YldC5E6V4IdSjCkz73UEubZDMc8ojsq
b1J+lOPQRByACDv7jtAGEhlsq/XrW7UGdoCxMjtDhAzyRzALh6/hqP+tgvIY
yqu0651NOhCO/54Z+ZFEhpwNNX3KZxAW79zskomQ4cO6L41B30Fo1pMDTTMi
ZLQ1dOyxXAghZbbkRBQHGeVcZXcwGHCk97WD6/cYMlpKMNxM14PgAbWnnAQS
GTuaeqUInkOwvZfX0hsOMubc17plEgws17cuwwuUc3X9M+5MAnNxYoFTZIOM
q6zXZN8oB2bZymYhk/LfWdxZ5zJg2dVY9quUIuNJH48AFRdgPpE3DMptEM2i
1H3u3n4I1mY0HLMkEc3uJaPoVASwYqxf7JlCiBauPxBevwlYawWJ9sJSREvZ
L2QHDgFz5a/fRiNEiHY7sWdo9Rywqrh+4dnUvO+gz6hZD7A8azKTGob+AzTJ
Zng=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Reaction coordinate\"", TraditionalForm], 
    FormBox[
     FractionBox[
     "\"Energy\"", 
      "\"\\!\\(\\*SuperscriptBox[\\\"Hartree\\\", \\\"2\\\"]\\)\""], 
     TraditionalForm]},
  AxesOrigin->{0, 0},
  ImageSize->{400, 300},
  PlotRange->{{-4.51393217, 4.45049773}, {-0.000037976130641708616`, 
   0.006671002595094453}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374275581310663`*^9, 3.4426843298779087`*^9}],

Cell[BoxData["\<\"Orange = IRC, Black = EVB\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374275581310663`*^9, 3.442684329975337*^9}],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374275581310663`*^9, 3.4426843299876633`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Maximum \\!\\(\\*SuperscriptBox[SubscriptBox[\\\"V\\\", \\\"12\
\\\"], \\\"2\\\"]\\) error along the IRC: \"\>", "\[InvisibleSpace]", 
   "0.0012524527584519098`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["\<\"Energy\"\>", \
"\<\"\\!\\(\\*SuperscriptBox[\\\"Hartree\\\", \\\"2\\\"]\\)\"\>"]}],
  SequenceForm[
  "Maximum \!\(\*SuperscriptBox[SubscriptBox[\"V\", \"12\"], \"2\"]\) error \
along the IRC: ", 0.0012524527584519098`, " ", "Energy"/
   "\!\(\*SuperscriptBox[\"Hartree\", \"2\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374275581310663`*^9, 3.442684329992481*^9}],

Cell[BoxData["\<\"\\!\\(\\*SuperscriptBox[SubscriptBox[\\\"V\\\", \
\\\"12\\\"], \\\"2\\\"]\\) error along the IRC:\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374275581310663`*^9, 3.442684330010694*^9}],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.6, 0.4, 0.2], Thickness[0.005], LineBox[CompressedData["
1:eJw91Xk01PsbB/Dv2HczIkV2UrYZ+1jyfMqSvZGpdHNvlkRdbjIulUjLbdEm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    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Reaction coordinate\"", TraditionalForm], 
    FormBox[
     FractionBox[
     "\"Energy\"", 
      "\"\\!\\(\\*SuperscriptBox[\\\"Hartree\\\", \\\"2\\\"]\\)\""], 
     TraditionalForm]},
  ImageSize->{400, 300},
  PlotRange->{-0.0012524527584519098`, 0.0012524527584519098`},
  PlotRangeClipping->True]], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374275581310663`*^9, 3.442684330025456*^9}],

Cell[BoxData["\<\"Gradient Norm along the IRC:\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374275581310663`*^9, 3.442684401874782*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0., 0.75, 0.], Thickness[0.005], LineBox[CompressedData["
1:eJw9knk01Asfxi0ztrHMEEpZU+raJlHc8P2JkkiJpMjutrwmNG5JpexbyTDG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     "]]}, 
   {RGBColor[1, 1, 0], Thickness[0.005], LineBox[CompressedData["
1:eJw9VXk0lA0fHcvYlxlSIhKyM8MbJi2/p1BIpVAqLTNDi6hEiMgWssVgZuyM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     "]]}, 
   {GrayLevel[0], Thickness[0.004], LineBox[CompressedData["
1:eJw9jAk01IsfxY2dMWaGRCq7VLahLBV9f8RLUiqpqbxi0PaQIjtllyX7GLLP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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Reaction coordinate\"", TraditionalForm], 
    FormBox["\"Gradient Norm\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  ImageSize->{400, 300},
  PlotRange->{{-4.51393217, 4.45049773}, {0., 0.04446993269412322}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374275581310663`*^9, 3.442684402032009*^9}],

Cell[BoxData["\<\"Green = Cartesian, Yellow = Red. Internal, Black = \
EVB\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374275581310663`*^9, 3.442684402152565*^9}],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374275581310663`*^9, 3.442684402224419*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Maximum Gradient Norm error along the IRC: \"\>", 
   "\[InvisibleSpace]", "0.01418280719832684`"}],
  SequenceForm[
  "Maximum Gradient Norm error along the IRC: ", 0.01418280719832684],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374275581310663`*^9, 3.442684402296258*^9}],

Cell[BoxData["\<\"Gradient Norm error along the IRC:\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374275581310663`*^9, 3.442684402364294*^9}],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.6, 0.4, 0.2], Thickness[0.005], LineBox[CompressedData["
1:eJw9lXk01A0Xx3+2ZBuG0GNLIT2PmKFkKrk/oSgp25OKrCU9psi+xAwzY5vK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    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Reaction coordinate\"", TraditionalForm], 
    FormBox["\"Gradient Norm\"", TraditionalForm]},
  ImageSize->{400, 300},
  PlotRange->{-0.01418280719832684, 0.01418280719832684},
  PlotRangeClipping->True]], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374275581310663`*^9, 3.442684402450141*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBinUse", "[", "]"}]], "Input",
 CellChangeTimes->{{3.4374073082264547`*^9, 3.437407310628818*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Currently using \"\>", "\[InvisibleSpace]", 
   "12.477935791015625`", "\[InvisibleSpace]", "\<\" MB of memory.\"\>"}],
  SequenceForm["Currently using ", 12.477935791015625`, " MB of memory."],
  Editable->False]], "Print",
 CellChangeTimes->{3.437407311125369*^9, 3.437408979449183*^9, 
  3.437413088450337*^9, 3.437413564045677*^9, 3.4426844027606363`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1130, 934},
WindowMargins->{{74, Automatic}, {4, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
ShowSelection->True,
Magnification->1.5,
FrontEndVersion->"6.0 for Mac OS X PowerPC (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3442665657-4847696"->{
  Cell[18622, 535, 254, 5, 60, "Print",
   CellTags->"Info3442665657-4847696"]},
 "Info3442665792-3485601"->{
  Cell[88250, 2170, 559, 9, 132, "Print",
   CellTags->"Info3442665792-3485601"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3442665657-4847696", 165430, 3549},
 {"Info3442665792-3485601", 165540, 3552}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 188, 2, 69, "Subtitle"],
Cell[781, 27, 1368, 23, 534, "Text"],
Cell[CellGroupData[{
Cell[2174, 54, 32, 0, 100, "Section"],
Cell[CellGroupData[{
Cell[2231, 58, 200, 5, 40, "Input"],
Cell[2434, 65, 649, 11, 40, "Output"]
}, Open  ]],
Cell[3098, 79, 58, 1, 40, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3193, 85, 24, 0, 100, "Section"],
Cell[3220, 87, 206, 4, 39, "Text"],
Cell[CellGroupData[{
Cell[3451, 95, 172, 4, 42, "Subsection"],
Cell[3626, 101, 233, 6, 42, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3896, 112, 244, 7, 42, "Subsection"],
Cell[4143, 121, 744, 19, 114, "Input"],
Cell[4890, 142, 412, 10, 65, "Input"],
Cell[5305, 154, 726, 23, 133, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6068, 182, 48, 0, 51, "Subsection"],
Cell[6119, 184, 539, 18, 64, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6695, 207, 116, 3, 51, "Subsection"],
Cell[6814, 212, 120, 3, 40, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6971, 220, 212, 5, 42, "Subsection"],
Cell[CellGroupData[{
Cell[7208, 229, 56, 1, 40, "Input"],
Cell[7267, 232, 494, 7, 40, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7810, 245, 278, 6, 42, "Subsection"],
Cell[8091, 253, 255, 6, 40, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8383, 264, 193, 4, 42, "Subsection"],
Cell[8579, 270, 152, 4, 40, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8780, 280, 28, 0, 100, "Section"],
Cell[CellGroupData[{
Cell[8833, 284, 62, 0, 37, "Subsubsection"],
Cell[8898, 286, 315, 9, 49, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9250, 300, 107, 2, 37, "Subsubsection"],
Cell[9360, 304, 259, 9, 42, "Input"],
Cell[9622, 315, 259, 9, 42, "Input"],
Cell[9884, 326, 228, 6, 42, "Input"],
Cell[10115, 334, 227, 6, 42, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10379, 345, 55, 1, 40, "Input"],
Cell[10437, 348, 736, 12, 30, "Print"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[11222, 366, 39, 0, 53, "Section"],
Cell[CellGroupData[{
Cell[11286, 370, 349, 6, 40, "Input"],
Cell[11638, 378, 905, 13, 40, "Output"]
}, Open  ]],
Cell[12558, 394, 1886, 40, 179, "Input"],
Cell[CellGroupData[{
Cell[14469, 438, 1611, 37, 179, "Input"],
Cell[16083, 477, 216, 3, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16336, 485, 62, 1, 40, "Input"],
Cell[16401, 488, 2069, 38, 147, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18507, 531, 112, 2, 40, "Input"],
Cell[18622, 535, 254, 5, 60, "Print",
 CellTags->"Info3442665657-4847696"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18913, 545, 1414, 26, 110, "Input"],
Cell[20330, 573, 405, 9, 53, "Print"],
Cell[20738, 584, 671, 16, 30, "Print"],
Cell[21412, 602, 671, 16, 30, "Print"],
Cell[22086, 620, 334, 8, 30, "Print"],
Cell[22423, 630, 186, 2, 30, "Print"],
Cell[22612, 634, 160, 2, 30, "Print"],
Cell[22775, 638, 174, 2, 30, "Print"],
Cell[22952, 642, 160, 2, 30, "Print"],
Cell[23115, 646, 167, 2, 30, "Print"],
Cell[23285, 650, 169, 2, 30, "Print"],
Cell[23457, 654, 158, 2, 30, "Print"],
Cell[23618, 658, 359, 7, 30, "Print"],
Cell[23980, 667, 366, 7, 30, "Print"],
Cell[24349, 676, 350, 7, 30, "Print"],
Cell[24702, 685, 6949, 218, 1417, "Print"],
Cell[31654, 905, 660, 15, 30, "Print"],
Cell[32317, 922, 169, 2, 30, "Print"],
Cell[32489, 926, 7197, 158, 115, "Print"],
Cell[39689, 1086, 166, 2, 30, "Print"],
Cell[39858, 1090, 10322, 167, 115, "Print"],
Cell[50183, 1259, 164, 2, 30, "Print"],
Cell[50350, 1263, 12192, 240, 135, "Print"],
Cell[62545, 1505, 442, 8, 30, "Print"],
Cell[62990, 1515, 309, 4, 30, "Print"],
Cell[63302, 1521, 8358, 147, 462, "Print"],
Cell[71663, 1670, 450, 10, 34, "Print"],
Cell[72116, 1682, 434, 10, 30, "Print"],
Cell[72553, 1694, 6951, 218, 1417, "Print"],
Cell[79507, 1914, 182, 2, 30, "Print"],
Cell[79692, 1918, 173, 2, 30, "Print"],
Cell[79868, 1922, 414, 9, 30, "Print"],
Cell[80285, 1933, 513, 11, 34, "Print"],
Cell[80801, 1946, 269, 6, 30, "Print"],
Cell[81073, 1954, 314, 7, 34, "Print"],
Cell[81390, 1963, 515, 13, 462, "Print"],
Cell[81908, 1978, 352, 7, 30, "Print"],
Cell[82263, 1987, 336, 7, 30, "Print"],
Cell[82602, 1996, 346, 7, 30, "Print"],
Cell[82951, 2005, 320, 7, 30, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83308, 2017, 183, 4, 42, "Subsection"],
Cell[83494, 2023, 310, 10, 40, "Input"],
Cell[CellGroupData[{
Cell[83829, 2037, 466, 12, 40, "Input"],
Cell[84298, 2051, 231, 3, 40, "Output"]
}, Open  ]],
Cell[84544, 2057, 200, 4, 40, "Input"],
Cell[CellGroupData[{
Cell[84769, 2065, 55, 1, 40, "Input"],
Cell[84827, 2068, 781, 13, 30, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[85669, 2088, 38, 0, 100, "Section"],
Cell[CellGroupData[{
Cell[85732, 2092, 1050, 31, 93, "Input"],
Cell[86785, 2125, 486, 13, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87308, 2143, 142, 2, 40, "Input"],
Cell[87453, 2147, 607, 13, 64, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[88097, 2165, 150, 3, 40, "Input"],
Cell[88250, 2170, 559, 9, 132, "Print",
 CellTags->"Info3442665792-3485601"]
}, Open  ]],
Cell[CellGroupData[{
Cell[88846, 2184, 470, 7, 40, "Input"],
Cell[89319, 2193, 693, 12, 30, "Print"],
Cell[90015, 2207, 490, 7, 30, "Print"],
Cell[90508, 2216, 12092, 209, 462, "Print"],
Cell[102603, 2427, 605, 9, 30, "Print"],
Cell[103211, 2438, 466, 7, 30, "Print"],
Cell[103680, 2447, 735, 13, 30, "Print"],
Cell[104418, 2462, 494, 7, 30, "Print"],
Cell[104915, 2471, 22116, 371, 462, 4528, 81, "CachedBoxData", "BoxData", \
"Print"],
Cell[127034, 2844, 558, 8, 34, "Print"],
Cell[127595, 2854, 8698, 156, 462, "Print"],
Cell[136296, 3012, 492, 7, 30, "Print"],
Cell[136791, 3021, 469, 7, 30, "Print"],
Cell[137263, 3030, 1040, 19, 54, "Print"],
Cell[138306, 3051, 564, 8, 34, "Print"],
Cell[138873, 3061, 4945, 88, 462, "Print"],
Cell[143821, 3151, 495, 7, 30, "Print"],
Cell[144319, 3160, 13037, 224, 462, "Print"],
Cell[157359, 3386, 523, 8, 30, "Print"],
Cell[157885, 3396, 467, 7, 30, "Print"],
Cell[158355, 3405, 699, 13, 30, "Print"],
Cell[159057, 3420, 501, 7, 30, "Print"],
Cell[159561, 3429, 4838, 84, 462, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[164436, 3518, 123, 2, 40, "Input"],
Cell[164562, 3522, 408, 7, 30, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
